@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdraster.c,v 1.47 2007/09/30 04:16:49 guru Exp $
+ *	$Id: grdraster.c,v 1.65 2010/03/24 22:58:40 jluis Exp $
  *
- *    Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /* grdraster.c -- read a rasterfile and extract a region as a grid file.
@@ -30,36 +30,39 @@
  *		27 Jun 2005   PW: Allow modifiers G(ographic) and C(artesian) in registration flag.
  *		19 Sep 2005   PW: Allow optional H<bytes> at end of line for skipping headers.
  *		07 Sep 2006   PW: Only do 360 wrap if geographic grid.
+ *		27 Apr 2009   PW: Added sanity check on file size (actual vs computed from grdraster.info)
  */
 
 #include "gmt.h"
 
 struct GRDRASTER_CTRL {
 	struct G {	/* -G<output_grdfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct I {	/* -Idx[/dy] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double xinc, yinc;
 	} I;
 };
 
 struct GRDRASTER_INFO {
 	struct GRD_HEADER h;
-	int	id;		/* File number  */
-	int	nglobal;	/* If not 0, ras is global and i%nglobal makes it periodic  */
-	int	nanflag;
-	int	nanset;		/* True if raster uses nanflag to signal NaN  */
-	int	skip;		/* Skip this number of header bytes when opeing file  */
+	GMT_LONG	id;		/* File number  */
+	GMT_LONG	nglobal;	/* If not 0, ras is global and i%nglobal makes it periodic  */
+	GMT_LONG	nanflag;
+	GMT_LONG	nanset;		/* True if raster uses nanflag to signal NaN  */
+	GMT_LONG	skip;		/* Skip this number of header bytes when opening file  */
 	char	type;
-	BOOLEAN swap_me;	/* TRUE if data set need to be swapped */
-	BOOLEAN geo;		/* TRUE if we believe x/y is lon/lat, FALSE otherwise */
+	GMT_LONG swap_me;	/* TRUE if data set need to be swapped */
+	GMT_LONG geo;		/* TRUE if we believe x/y is lon/lat, FALSE otherwise */
 };
 
+GMT_LONG get_byte_size (char type);
+
 int main (int argc, char **argv)
 {
-	BOOLEAN xyz_out = FALSE;
+	GMT_LONG xyz_out = FALSE;
 
 #if WORDS_BIGENDIAN == 0
 	char my_endian = 'L';	/* This machine is Little endian */
@@ -70,9 +73,9 @@ int main (int argc, char **argv)
 	unsigned char *ubuffer = NULL;
 	static unsigned char maskset[8] = {128, 64, 32, 16, 8, 4, 2, 1};
 	
-	int	i, j, k, ksize = 0, iselect, nselected = 0, imult, jmult, nrasters, ij_offset;
-	int	irasstart, jrasstart, n_nan, iras, jras, ij, ijras, jseek, nmask = 0;
-	int	error = FALSE, firstread;
+	GMT_LONG	i, j, k, ksize = 0, iselect, nselected = 0, imult, jmult, nrasters, ij_offset;
+	GMT_LONG	irasstart, jrasstart, n_nan, iras, jras, ij, ijras, jseek, nmask = 0;
+	GMT_LONG	error = FALSE, firstread, nm;
 	
 	float	*grd = NULL, *floatrasrow = NULL;
 	
@@ -88,17 +91,17 @@ int main (int argc, char **argv)
 
 	struct GRDRASTER_CTRL *Ctrl;
 	
-	void *New_Grdraster_Ctrl (), Free_Grdraster_Ctrl (struct GRDRASTER_CTRL *C);
+	void *New_grdraster_Ctrl (), Free_grdraster_Ctrl (struct GRDRASTER_CTRL *C);
 	void convert_u_row (struct GRDRASTER_INFO ras, float *row, unsigned char *buffer);
 	void convert_c_row (struct GRDRASTER_INFO ras, float *row, char *buffer);
 	void convert_d_row (struct GRDRASTER_INFO ras, float *row, short unsigned int *buffer);
 	void convert_i_row (struct GRDRASTER_INFO ras, float *row, short int *buffer);
 	void convert_l_row (struct GRDRASTER_INFO ras, float *row, int *buffer);
-	int load_rasinfo (struct GRDRASTER_INFO **rasinfo, char endian);
+	GMT_LONG load_rasinfo (struct GRDRASTER_INFO **rasinfo, char endian);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDRASTER_CTRL *)New_Grdraster_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDRASTER_CTRL *)New_grdraster_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	GMT_grd_init (&h, argc, argv, FALSE);
 
@@ -181,6 +184,8 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
+	GMT_check_lattice (&Ctrl->I.xinc, &Ctrl->I.yinc, NULL, &Ctrl->I.active);
+
 	/* Check that arguments were valid:  */
 	if (!project_info.region_supplied) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify -R option\n", GMT_program);
@@ -230,7 +235,7 @@ int main (int argc, char **argv)
 		}
 		if (j == -1) {
 			if (iselect != -1)
-				fprintf (stderr, "%s ERROR:  No raster with file number %d in grdraster.info\n", GMT_program, iselect);
+				fprintf (stderr, "%s ERROR:  No raster with file number %ld in grdraster.info\n", GMT_program, iselect);
 			else
 				fprintf (stderr, "%s ERROR:  No raster with text %s in grdraster.info\n", GMT_program, tselect);
 			error++;
@@ -266,7 +271,7 @@ int main (int argc, char **argv)
 		imult = jmult = 1;
 	}
 
-	if (!project_info.region && project_info.projection >= 0) {
+	if (!project_info.region && project_info.projection != GMT_NO_PROJ) {
 	
 		GMT_err_fail (GMT_map_setup (h.x_min, h.x_max, h.y_min, h.y_max), "");
 		
@@ -276,13 +281,13 @@ int main (int argc, char **argv)
 		h.y_max = ceil (project_info.n / h.y_inc) * h.y_inc;
 		
 		if (gmtdefs.verbose && rint (h.x_inc * 60.0) == (h.x_inc * 60.0)) {	/* Spacing in even minutes */
-			int w, e, s, n, wm, em, sm, nm;
+			GMT_LONG w, e, s, n, wm, em, sm, nm;
 			
-			w = (int) floor (h.x_min);	wm = irint ((h.x_min - w) * 60.0);
-			e = (int) floor (h.x_max);	em = irint ((h.x_max - e) * 60.0);
-			s = (int) floor (h.y_min);	sm = irint ((h.y_min - s) * 60.0);
-			n = (int) floor (h.y_max);	nm = irint ((h.y_max - n) * 60.0);
-			fprintf (stderr, "%s: %s -> -R%d:%2.2d/%d:%2.2d/%d:%2.2d/%d:%2.2d\n", GMT_program, r_opt, w, wm, e, em, s, sm, n, nm);
+			w = (GMT_LONG) floor (h.x_min);	wm = (GMT_LONG) irint ((h.x_min - w) * 60.0);
+			e = (GMT_LONG) floor (h.x_max);	em = (GMT_LONG) irint ((h.x_max - e) * 60.0);
+			s = (GMT_LONG) floor (h.y_min);	sm = (GMT_LONG) irint ((h.y_min - s) * 60.0);
+			n = (GMT_LONG) floor (h.y_max);	nm = (GMT_LONG) irint ((h.y_max - n) * 60.0);
+			fprintf (stderr, "%s: %s -> -R%ld:%2.2ld/%ld:%2.2ld/%ld:%2.2ld/%ld:%2.2ld\n", GMT_program, r_opt, w, wm, e, em, s, sm, n, nm);
 		}
 		else if (gmtdefs.verbose)
 			fprintf (stderr, "%s: %s -> -R%g/%g/%g/%g\n", GMT_program, r_opt, h.x_min, h.x_max, h.y_min, h.y_max);
@@ -304,15 +309,15 @@ int main (int argc, char **argv)
 		h.ny = irint ((h.y_max - h.y_min) / h.y_inc);
 		fprintf(stderr, "%s WARNING:  Your -R option does not create a region divisible by x_inc, y_inc.\n", GMT_program);
 		if (GMT_IS_ZERO (rint (h.x_inc * 60.0) - h.x_inc * 60.0)) {	/* Spacing in even minutes */
-			int w, e, s, n, wm, em, sm, nm;
-			w = (int) floor (h.x_min);	wm = irint ((h.x_min - w) * 60.0);
-			e = (int) floor (h.x_max);	em = irint ((h.x_max - e) * 60.0);
-			s = (int) floor (h.y_min);	sm = irint ((h.y_min - s) * 60.0);
-			n = (int) floor (h.y_max);	nm = irint ((h.y_max - n) * 60.0);
+			GMT_LONG w, e, s, n, wm, em, sm, nm;
+			w = (GMT_LONG) floor (h.x_min);	wm = (GMT_LONG) irint ((h.x_min - w) * 60.0);
+			e = (GMT_LONG) floor (h.x_max);	em = (GMT_LONG) irint ((h.x_max - e) * 60.0);
+			s = (GMT_LONG) floor (h.y_min);	sm = (GMT_LONG) irint ((h.y_min - s) * 60.0);
+			n = (GMT_LONG) floor (h.y_max);	nm = (GMT_LONG) irint ((h.y_max - n) * 60.0);
 			if (project_info.region)
-				fprintf(stderr, "%s WARNING:  Region reset to -R%d:%2.2d/%d:%2.2d/%d:%2.2d/%d:%2.2d.\n", GMT_program, w, wm, e, em, s, sm, n, nm);
+				fprintf(stderr, "%s WARNING:  Region reset to -R%ld:%2.2ld/%ld:%2.2ld/%ld:%2.2ld/%ld:%2.2ld.\n", GMT_program, w, wm, e, em, s, sm, n, nm);
 			else
-				fprintf(stderr, "%s WARNING:  Region reset to -R%d:%2.2d/%d:%2.2d/%d:%2.2d/%d:%2.2dr\n", GMT_program, w, wm, s, sm, e, em, n, nm);
+				fprintf(stderr, "%s WARNING:  Region reset to -R%ld:%2.2ld/%ld:%2.2ld/%ld:%2.2ld/%ld:%2.2ldr\n", GMT_program, w, wm, s, sm, e, em, n, nm);
 		}
 		else {
 			if (project_info.region)
@@ -361,31 +366,17 @@ int main (int argc, char **argv)
 		for (i = 0; i < h.nx; i++) x[i] = GMT_i_to_x (i, h.x_min, h.x_max, h.x_inc, h.xy_off, h.nx);
 		ij_offset = 0;
 	} else {	/* Need entire grid */
-		grd = (float *)GMT_memory(VNULL, (size_t)(h.nx*h.ny), sizeof(float), GMT_program);
+		nm = GMT_get_nm (h.nx, h.ny);
+		grd = (float *)GMT_memory(VNULL, (size_t)nm, sizeof(float), GMT_program);
 		ij_offset = h.nx;
 	}
 	
-	if (myras.type == 'b') {
-		/* Need to read the whole thing:  */
-		nmask = (int)ceil (myras.h.nx * myras.h.ny * 0.125);
+	ksize = get_byte_size (myras.type);
+	if (ksize == 0) {	/* Bits; Need to read the whole thing:  */
+		nmask = (GMT_LONG)ceil (myras.h.nx * myras.h.ny * 0.125);
 		ubuffer = (unsigned char *)GMT_memory(VNULL, (size_t)nmask, (size_t)1, GMT_program);
 	}
-	else {
-		/* Need to read by rows, and convert each row to float:  */
-		switch (myras.type) {
-			case 'c':
-			case 'u':
-				ksize = 1;
-				break;
-			case 'd':
-			case 'h':
-			case 'i':
-				ksize = 2;
-				break;
-			case 'l':
-				ksize = 4;
-				break;
-		}
+	else {	/* Need to read by rows, and convert each row to float:  */
 		buffer = GMT_memory (VNULL, (size_t)myras.h.nx, (size_t)ksize, GMT_program);
 		floatrasrow = (float *)GMT_memory(VNULL, (size_t)myras.h.nx, sizeof(float), GMT_program);
 	}
@@ -397,7 +388,7 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 	if (myras.skip && fseek (fp, (long) (myras.skip), SEEK_CUR) ) {
-		fprintf(stderr,"%s ERROR skipping %d bytes in %s.\n", GMT_program, myras.skip, myras.h.remark);
+		fprintf(stderr,"%s ERROR skipping %ld bytes in %s.\n", GMT_program, myras.skip, myras.h.remark);
 		exit (EXIT_FAILURE);
 	}
 	if (gmtdefs.verbose) fprintf(stderr, "%s:  Reading from raster %s\n", GMT_program, myras.h.remark);
@@ -481,7 +472,7 @@ int main (int argc, char **argv)
 					exit (EXIT_FAILURE);
 				}
 #ifdef DEBUG
-				fprintf (stderr, "%s: Doing line %6.6d\r", GMT_program, j);
+				fprintf (stderr, "%s: Doing line %6.6ld\r", GMT_program, j);
 #endif
 				switch (myras.type) {
 					case 'u':
@@ -530,7 +521,7 @@ int main (int argc, char **argv)
 	fclose(fp);
 
 	if (gmtdefs.verbose) fprintf (stderr, "%s:  Finished reading from %s\n", GMT_program, myras.h.remark);
-	if (gmtdefs.verbose) fprintf (stderr, "%s:  min max and # NaN found: %g %g %d\n", GMT_program, h.z_min, h.z_max, n_nan);
+	if (gmtdefs.verbose) fprintf (stderr, "%s:  min max and # NaN found: %g %g %ld\n", GMT_program, h.z_min, h.z_max, n_nan);
 
 	if (n_nan == h.nx * h.ny) fprintf(stderr,"%s: WARNING - Your grid file is entirely full of NaNs.\n", GMT_program);
 
@@ -543,7 +534,7 @@ int main (int argc, char **argv)
 	GMT_free ((void *)grd);
 	GMT_free ((void *)rasinfo);
 
-	Free_Grdraster_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdraster_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 	
@@ -552,9 +543,9 @@ int main (int argc, char **argv)
 
 void convert_u_row(struct GRDRASTER_INFO ras, float *row, unsigned char *buffer)
 {
-	int	i, tempval;
+	GMT_LONG	i, tempval;
 	for (i = 0; i < ras.h.nx; i++) {
-		tempval = (int)buffer[i];
+		tempval = (GMT_LONG)buffer[i];
 		if (ras.nanset && tempval == ras.nanflag) {
 			row[i] = GMT_f_NaN;
 		}
@@ -569,9 +560,9 @@ void convert_u_row(struct GRDRASTER_INFO ras, float *row, unsigned char *buffer)
 
 void convert_c_row(struct GRDRASTER_INFO ras, float *row, char *buffer)
 {
-	int	i, tempval;
+	GMT_LONG	i, tempval;
 	for (i = 0; i < ras.h.nx; i++) {
-		tempval = (int)buffer[i];
+		tempval = (GMT_LONG)buffer[i];
 		if (ras.nanset && tempval == ras.nanflag) {
 			row[i] = GMT_f_NaN;
 		}
@@ -586,7 +577,7 @@ void convert_c_row(struct GRDRASTER_INFO ras, float *row, char *buffer)
 
 void convert_d_row(struct GRDRASTER_INFO ras, float *row, short unsigned int *buffer)
 {
-	int	i, tempval;
+	GMT_LONG	i, tempval;
 	for (i = 0; i < ras.h.nx; i++) {
 		if (ras.swap_me) buffer[i] = GMT_swab2 (buffer[i]);
 
@@ -605,7 +596,7 @@ void convert_d_row(struct GRDRASTER_INFO ras, float *row, short unsigned int *bu
 
 void convert_i_row(struct GRDRASTER_INFO ras, float *row, short int *buffer)
 {
-	int	i, tempval;
+	GMT_LONG	i, tempval;
 	for (i = 0; i < ras.h.nx; i++) {
 		if (ras.swap_me) buffer[i] = GMT_swab2 (buffer[i]);
 
@@ -624,7 +615,7 @@ void convert_i_row(struct GRDRASTER_INFO ras, float *row, short int *buffer)
 
 void convert_l_row(struct GRDRASTER_INFO ras, float *row, int *buffer)
 {
-	int	i, tempval;
+	GMT_LONG	i, tempval;
 	for (i = 0; i < ras.h.nx; i++) {
 		if (ras.swap_me) buffer[i] = GMT_swab4 (buffer[i]);
 
@@ -641,7 +632,7 @@ void convert_l_row(struct GRDRASTER_INFO ras, float *row, int *buffer)
 	return;
 }
 
-int	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
+GMT_LONG	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 {
 	/* Read the file grdraster.info
 		Store the i'th row of the file in rasinfo[i].h.command.
@@ -656,17 +647,19 @@ int	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 
 	Return 0 if cannot read files correctly, or nrasters if successful.  */
 
-	int	i, j, length, stop_point, nfound = 0;
+	GMT_LONG	i, j, length, stop_point, nfound = 0, ksize = 0;
 	size_t	n_alloc;
+	off_t expected_size;
 	double	global_lon, lon_tol;
 	char	buf[GRD_REMARK_LEN], dir[GRD_REMARK_LEN], *l;
 	FILE	*fp;
 	struct GRDRASTER_INFO *rasinfo;
+	struct STAT F;
 
 	/* Find and open the file grdraster.info */
 
 	if (!(GMT_getdatapath("grdraster.info", dir) || GMT_getsharepath("dbase", "grdraster", ".info", dir))) {
-		fprintf(stderr, "%s: ERROR cannot find file grdraster.info", GMT_program);
+		fprintf(stderr, "%s: ERROR cannot find file grdraster.info\n", GMT_program);
 		return (0);
 	}
 
@@ -684,12 +677,10 @@ int	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 	
 	while (fgets(rasinfo[nfound].h.command, GRD_COMMAND_LEN, fp) ) {
 		if (rasinfo[nfound].h.command[0] == '#') continue;
-		if (rasinfo[nfound].h.command[0] == '\n') continue;	 /* Blank line */
+		GMT_chop (rasinfo[nfound].h.command);
+		if (rasinfo[nfound].h.command[0] == '\0') continue;	 /* Blank line */
 
-		/* Strip off the trailing "\n" :  */
 		length = strlen(rasinfo[nfound].h.command);
-		length--;
-		rasinfo[nfound].h.command[length] = '\0';
 
 		/* Find the integer file name first:  */
 		i = 0;
@@ -709,7 +700,7 @@ int	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 		
 		strncpy(buf, &rasinfo[nfound].h.command[i], (size_t)j-i);
 		buf[j-i] = '\0';
-		if ( (sscanf(buf, "%d", &rasinfo[nfound].id) ) != 1) {
+		if ( (sscanf(buf, "%" GMT_LL "d", &rasinfo[nfound].id) ) != 1) {
 			fprintf(stderr,"%s: error reading grdraster.info\n", GMT_program);
 			fprintf(stderr,"\tFile number conversion error.\n");
 			return(0);
@@ -933,7 +924,7 @@ int	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 		}
 		else {
 			rasinfo[nfound].nanset = 1;
-			if ( (sscanf(buf, "%d", &rasinfo[nfound].nanflag) ) != 1) {
+			if ( (sscanf(buf, "%" GMT_LL "d", &rasinfo[nfound].nanflag) ) != 1) {
 				fprintf(stderr,"%s: error reading grdraster.info\n", GMT_program);
 				fprintf(stderr,"\tNaN flag conversion error.\n");
 				return(0);
@@ -1033,33 +1024,71 @@ int	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 		rasinfo[nfound].h.command[stop_point] = '\0';
 
 		i = irint( (rasinfo[nfound].h.x_max - rasinfo[nfound].h.x_min)/rasinfo[nfound].h.x_inc);
-		rasinfo[nfound].h.nx = (rasinfo[nfound].h.node_offset) ? i : i + 1;
+		rasinfo[nfound].h.nx = (int)((rasinfo[nfound].h.node_offset) ? i : i + 1);
 		j = irint( (rasinfo[nfound].h.y_max - rasinfo[nfound].h.y_min)/rasinfo[nfound].h.y_inc);
-		rasinfo[nfound].h.ny = (rasinfo[nfound].h.node_offset) ? j : j + 1;
+		rasinfo[nfound].h.ny = (int)((rasinfo[nfound].h.node_offset) ? j : j + 1);
 		
+		if ((ksize = get_byte_size (rasinfo[nfound].type)) == 0)
+			expected_size = (off_t)(ceil (GMT_get_nm (rasinfo[nfound].h.nx, rasinfo[nfound].h.ny) * 0.125) + rasinfo[nfound].skip);
+		else
+			expected_size = (off_t)(GMT_get_nm (rasinfo[nfound].h.nx, rasinfo[nfound].h.ny) * ksize + rasinfo[nfound].skip);
+		if (STAT (rasinfo[nfound].h.remark, &F)) {	/* Inquiry about file failed somehow */
+			fprintf (stderr, "%s: Warning: Unable to stat file %s\n", GMT_program, rasinfo[nfound].h.remark);
+		}
+		else if (F.st_size != expected_size) {
+			fprintf (stderr, "%s: Actual size of file %s [%ld] differs from expected [%ld]. Verify file and its grdraster.info details.\n", GMT_program, rasinfo[nfound].h.remark, (GMT_LONG)F.st_size, (GMT_LONG)expected_size);
+			exit (EXIT_FAILURE);
+		}
 		nfound++;
 		
 		if ((size_t)nfound == n_alloc) {
-			n_alloc += GMT_SMALL_CHUNK;
-			rasinfo = (struct GRDRASTER_INFO *) GMT_memory ((void *)rasinfo, n_alloc, sizeof (struct GRDRASTER_INFO), GMT_program);
+			n_alloc <<= 1;
+			rasinfo = (struct GRDRASTER_INFO *) GMT_memory ((void *)rasinfo, (size_t)n_alloc, sizeof (struct GRDRASTER_INFO), GMT_program);
 		}
 	}
 	fclose (fp);
-	if (nfound > 0) rasinfo = (struct GRDRASTER_INFO *) GMT_memory ((void *)rasinfo, nfound, sizeof (struct GRDRASTER_INFO), GMT_program);
+	if (nfound > 0) rasinfo = (struct GRDRASTER_INFO *) GMT_memory ((void *)rasinfo, (size_t)nfound, sizeof (struct GRDRASTER_INFO), GMT_program);
 	
 	*ras = rasinfo;
 	return (nfound);
 }
 
-void *New_Grdraster_Ctrl () {	/* Allocate and initialize a new control structure */
+GMT_LONG get_byte_size (char type) {
+	/* Return byte size of each item, or 0 if bits */
+	int ksize;
+	switch (type) {
+		case 'b':
+			ksize = 0;
+			break;
+		case 'c':
+		case 'u':
+			ksize = 1;
+			break;
+		case 'd':
+		case 'h':
+		case 'i':
+			ksize = 2;
+			break;
+		case 'l':
+			ksize = 4;
+			break;
+		default:
+			fprintf (stderr, "%s: ERROR: Invalid data type [%c]\n", GMT_program, type);
+			exit (EXIT_FAILURE);
+			break;
+	}
+	return (ksize);
+}
+
+void *New_grdraster_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDRASTER_CTRL *C;
 	
-	C = (struct GRDRASTER_CTRL *) GMT_memory (VNULL, 1, sizeof (struct GRDRASTER_CTRL), "New_Grdraster_Ctrl");
+	C = (struct GRDRASTER_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDRASTER_CTRL), "New_grdraster_Ctrl");
 	
 	return ((void *)C);
 }
 
-void Free_Grdraster_Ctrl (struct GRDRASTER_CTRL *C) {	/* Deallocate control structure */
+void Free_grdraster_Ctrl (struct GRDRASTER_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);	
 	GMT_free ((void *)C);	
 }
