@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77magref.c,v 1.20 2009/07/07 08:17:21 guru Exp $
+ *	$Id: mgd77magref.c,v 1.26 2010/06/25 20:33:49 guru Exp $
  *
- *    Copyright (c) 2009 by J. Luis and P. Wessel
+ *    Copyright (c) 2009-2010 by J. Luis and P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -21,9 +21,11 @@ int main (int argc, char **argv) {
 	int i, j, s, pos_slash = 0, nval = 0, nfval = 0, fno, n_files = 0, error = 0, n_args, t_col = 3, n_out = 0;
 	int lval = 0, lfval = 0, n_field_components, this_i;
 	GMT_LONG pos;
-	BOOLEAN nofile = TRUE, copy_input = FALSE, time_in_years = FALSE, fixed_alt = FALSE, fixed_time = FALSE, do_IGRF = FALSE, done;
+	GMT_LONG nofile = TRUE, copy_input = FALSE, time_in_years = FALSE, fixed_alt = FALSE, fixed_time = FALSE;
+	GMT_LONG do_CM4 = TRUE, joint_IGRF_CM4 = FALSE, do_IGRF = FALSE, cm4_igrf_T = FALSE, done;
 	size_t n_alloc = 0, need = 0;
-	double	the_altitude, the_time, *time_array = NULL, *alt_array = NULL, *time_years = NULL, IGRF[7], out[BUFSIZ];
+	double	the_altitude, the_time, *time_array = NULL, *alt_array = NULL, *time_years = NULL, IGRF[7], out[GMT_MAX_COLUMNS];
+	double	*igrf_xyz = NULL;	/* Temporary storage for the joint_IGRF_CM4 case */
 	char p[GMT_LONG_TEXT], txt[GMT_LONG_TEXT];
 	FILE *fp;
 	struct MGD77_CONTROL M;
@@ -35,6 +37,8 @@ int main (int argc, char **argv) {
 
 	argc = GMT_begin (argc, argv);		/* Initialize GMT Machinery */
 	
+	GMT_get_time_system ("unix", &(gmtdefs.time_system));						/* MGD77+ uses GMT's Unix time epoch */
+	GMT_init_time_system_structure (&(gmtdefs.time_system));
 	MGD77_Init (&M);			/* Initialize MGD77 Machinery */
 
 	MGD77_CM4_init (&M, Ctrl);		/* Presets path using strdup */
@@ -71,6 +75,7 @@ int main (int argc, char **argv) {
 							case 't':
 								fixed_time = TRUE;
 								the_time = atof (&p[1]);
+								GMT_io.out_col_type[3] = GMT_IS_FLOAT;
 								break;
 							case 'y':
 								time_in_years = TRUE;
@@ -152,6 +157,8 @@ int main (int argc, char **argv) {
 							switch (argv[i][j]) {
 								case '0':		/* IGRF */
 									do_IGRF = TRUE;
+									do_CM4  = FALSE;
+									joint_IGRF_CM4 = FALSE;
 									break;
 								case '1':		/* Main field 1 */
 									Ctrl->F.field_sources[nfval++] = 0; 
@@ -174,6 +181,11 @@ int main (int argc, char **argv) {
 								case '7':		/* Toroidal field */
 									Ctrl->F.field_sources[nfval++] = 6; 
 									break;
+								case '9':		/* Main field is computed with the IGRF */
+									do_IGRF = FALSE;/* No contradiction, the way will be through joint_IGRF_CM4 */
+									do_CM4  = TRUE;	/* Well maybe, if some other source is selected also */
+									joint_IGRF_CM4 = TRUE;
+									break;
 							}
 						}
 						Ctrl->F.n_field_sources = nfval; 
@@ -260,7 +272,7 @@ int main (int argc, char **argv) {
 	if (error || GMT_give_synopsis_and_exit) {	/* Display usage */
 		fprintf (stderr, "mgd77magref %s - Evaluating the IGRF or CM4 magnetic field models\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: mgd77magref [<inputfile>] [-A+y+a<alt>+t<date>] [-C<cm4file>] [-D<dstfile>] [-E<f107file>]\n");
-		fprintf (stderr, "\t[-F<rthxyzdi[/01234567]>] [-G] [%s] [-L<rtxyz[/1234]>] [-Sc|l<low/high>]\n", GMT_H_OPT);
+		fprintf (stderr, "\t[-F<rthxyzdi[/[0|9]1234567]>] [-G] [%s] [-L<rtxyz[/1234]>] [-Sc|l<low/high>]\n", GMT_H_OPT);
 		fprintf (stderr, "\t[-V] [%s] [%s] [%s]\n\n", GMT_t_OPT, GMT_b_OPT, GMT_m_OPT);
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -297,9 +309,12 @@ int main (int argc, char **argv) {
 		fprintf (stderr, "\t	 5 Primary ionospheric field.\n");
 		fprintf (stderr, "\t	 6 Induced ionospheric field.\n");
 		fprintf (stderr, "\t	 7 Toroidal field.\n");
+		fprintf (stderr, "\t	 9 means Core field from IGRF and other contributions from CM4. DO NOT USE BOTH 0 AND 9.\n");
 		fprintf (stderr, "\t   Append several numbers to add up the different contributions. For example,\n");
 		fprintf (stderr, "\t     -Ft/12 computes the total field due to CM4 Core and Lithospheric sources.\n");
-		fprintf (stderr, "\t     Note that 0 (IGRF) cannot be combined with other contributions.\n");
+		fprintf (stderr, "\t     Two special cases are allowed wich mix which Core field from IGRF and other sources from CM4.\n");
+		fprintf (stderr, "\t     -Ft/934 computes Core field due to IGRF plus terms 3 and 4 from CM4.\n");
+		fprintf (stderr, "\t     -Fxyz/934 the same as above but output the field components.\n");
 		fprintf (stderr, "\t	 The data is written out in the order specified in <dataflags>\n");
 		fprintf (stderr, "\t	 [Default is -Frthxyzdi/1]\n");
 		fprintf (stderr, "\t-G Specifies that coordinates are geocentric [geodetic].\n");
@@ -343,18 +358,46 @@ int main (int argc, char **argv) {
 		error++;
 	}
 
+	if ( nfval && do_IGRF )
+		fprintf (stderr, "%s: WARNING. Source fields other than IGRF will be ignored. It's in the manual\n", GMT_program);
+
+	/* ------------- Test, and take measures, if mix mode IGRF/CM4 is to be used -------------------------- */
+	if (joint_IGRF_CM4) {
+		if (nfval == 0) {	/* It means we had a -F.../9 which is exactly iqual to -F.../0 */
+			do_IGRF = TRUE;
+			do_CM4  = FALSE;
+			joint_IGRF_CM4 = FALSE;
+		}
+		else {
+			cm4_igrf_T = FALSE;
+			if ( (nval == 1) && (Ctrl->F.field_components[0] == 0) ) {
+				for (i = 0; i < 3; i++) Ctrl->F.field_components[i] = i+2;	/* Force the x,y,z request */
+				cm4_igrf_T = TRUE;
+			}
+			else if ( !((nval == 3) && 
+				(Ctrl->F.field_components[0] == 2) && (Ctrl->F.field_components[1] == 3) && (Ctrl->F.field_components[2] == 4)) ) {
+				fprintf (stderr, "%s: GMT ERROR. In mix CM4/IGRF mode -F option can oly be -Ft[r]/... or -Fxyz[r]/...\n", GMT_program);
+				error++;
+			}
+
+			nval = 3;
+			Ctrl->F.n_field_components = nval; 
+		}
+	}
+	/* ----------------------------------------------------------------------------------------------------- */
+
 	if (error) exit (EXIT_FAILURE);
 
 	if (!Ctrl->F.active && !Ctrl->L.curr) Ctrl->F.active = TRUE;
 
 	/* Sort the order in which the parameters appear */
 	if (Ctrl->F.active) {
-		if (nval == 0) {		/* Nothing selected, default used */
+		if (nval == 0) {		/* No components selected, default used */
 			copy_input = TRUE;
 			Ctrl->F.n_field_components = 7;
 			for (i = 0; i < 7; i++) Ctrl->F.field_components[i] = i;
 		}
-		if (nfval == 0) {		/* Nothing selected, retain only the main field */
+		if (nfval == 0 && !joint_IGRF_CM4) {		/* No sources selected, retain only the main field */
 			Ctrl->F.field_sources[0] = 0; 
 			Ctrl->F.n_field_sources = 1;
 		}
@@ -389,6 +432,7 @@ int main (int argc, char **argv) {
 	}
 	else	/* Make sure input time columns are encoded/decoded properly since here we know t_col is set. */
 		GMT_io.in_col_type[t_col] = GMT_io.out_col_type[t_col] = (time_in_years) ? GMT_IS_FLOAT : GMT_IS_ABSTIME;
+
 	GMT_io.in_col_type[t_col+1] = GMT_io.out_col_type[t_col+1] = GMT_IS_FLOAT;		/* Override any previous t_col = 3 settings */
 	if (!copy_input) GMT_io.out_col_type[2] = GMT_io.out_col_type[3] = GMT_IS_FLOAT;	/* No time on output */
 	
@@ -433,12 +477,18 @@ int main (int argc, char **argv) {
 			if (need > n_alloc) {	/* Need to reallocate */
 				n_alloc = need;
 				Ctrl->DATA.out_field = (double *) GMT_memory ((void *)Ctrl->DATA.out_field, n_alloc * n_field_components, sizeof(double), GMT_program);
-				if (!(time_in_years || fixed_time)) time_years = (double *) GMT_memory ((void *)time_years, n_alloc, sizeof(double), GMT_program);
+				if (!(time_in_years || fixed_time)) 
+					time_years = (double *) GMT_memory ((void *)time_years, n_alloc, sizeof(double), GMT_program);
+
+				if (joint_IGRF_CM4)
+					igrf_xyz = (double *) GMT_memory ((void *)igrf_xyz, n_alloc * 3, sizeof(double), GMT_program);
 			}
+
 			if (!fixed_alt) {	/* Assign the alt_array to the provided altitude array */
 				alt_array = T->segment[s]->coord[GMT_Z];
 				Ctrl->DATA.n_altitudes = T->segment[s]->n_rows;
 			}
+
 			if (!fixed_time) {	/* Assign the time_array to the provided time array */
 				Ctrl->DATA.n_times = T->segment[s]->n_rows;
 				if (time_in_years)
@@ -448,14 +498,15 @@ int main (int argc, char **argv) {
 						time_years[i] = MGD77_time_to_fyear (&M, T->segment[s]->coord[t_col][i]);
 					time_array = time_years;
 				}
-				if (!do_IGRF && !s && time_array[0] > 2002.7) {		/* Only atmospheric terms may be reliable */
-					fprintf (stderr, "%s: WARNING. Time is outside the CM4 strict validity domain [1960-2002.7].\n", GMT_program);
-					fprintf (stderr, "\tThough extended here to 2006 the secular variation estimation will be unreliable.\n");
-				}
-			
 			}
+
+			if (!(do_IGRF || joint_IGRF_CM4 ) && !s && time_array[0] > 2002.7) {	/* Only atmospheric terms may be reliable */
+				fprintf (stderr, "%s: WARNING. Time is outside the CM4 strict validity domain [1960-2002.7].\n", GMT_program);
+				fprintf (stderr, "\tThough extended here to 2009 the secular variation estimation will be unreliable.\n");
+			}
+
 			Ctrl->DATA.n_pts = T->segment[s]->n_rows;
-			if (do_IGRF) {
+			if (do_IGRF || joint_IGRF_CM4) {
 				int type;
 				type = (Ctrl->G.geodetic) ? 1 : 2;
 				for (i = 0; i < T->segment[s]->n_rows; i++) {
@@ -464,19 +515,50 @@ int main (int argc, char **argv) {
 					if (type == 2) the_altitude += 6371.2;
 					MGD77_igrf10syn (0, the_time, type, the_altitude, T->segment[s]->coord[GMT_X][i], 
 							T->segment[s]->coord[GMT_Y][i], IGRF);
-					for (j = 0; j < Ctrl->F.n_field_components; j++) 
-						Ctrl->DATA.out_field[i*n_field_components+j] = IGRF[Ctrl->F.field_components[j]];
+					if (!joint_IGRF_CM4) {		/* IGRF only */
+						for (j = 0; j < Ctrl->F.n_field_components; j++) 
+							Ctrl->DATA.out_field[i*n_field_components+j] = IGRF[Ctrl->F.field_components[j]];
+					}
+					else {				/* Store the IGRF x,y,z components for later use */
+						for (j = 0; j < 3; j++) 
+							igrf_xyz[i*3+j] = IGRF[Ctrl->F.field_components[j]];
+					}
 				}
 			}
-			else {	/* DO CM4 */
-				MGD77_cm4field (Ctrl, T->segment[s]->coord[GMT_X], T->segment[s]->coord[GMT_Y], alt_array, time_array);	/* Eval CM4 at all points */
+
+			if (do_CM4) 				/* DO CM4 only. Eval CM4 at all points */
+				MGD77_cm4field (Ctrl, T->segment[s]->coord[GMT_X], T->segment[s]->coord[GMT_Y], alt_array, time_array);
+
+			if ((do_CM4 || do_IGRF) && !joint_IGRF_CM4) {	/* DID CM4 or (exclusive) IGRF only. */
+				for (i = 0; i < T->segment[s]->n_rows; i++) {	/* Output the requested columns */
+					n_out = 0;
+					if (copy_input) for (j = 0; j < T->segment[s]->n_columns; j++) out[n_out++] = T->segment[s]->coord[j][i];
+					for (j = 0; j < n_field_components; j++)
+						out[n_out++] = Ctrl->DATA.out_field[i*n_field_components+j];
+
+					GMT_output (GMT_stdout, n_out, out);
+				}
 			}
-			for (i = 0; i < T->segment[s]->n_rows; i++) {	/* Output the requested columns */
-				n_out = 0;
-				if (copy_input) for (j = 0; j < T->segment[s]->n_columns; j++) out[n_out++] = T->segment[s]->coord[j][i];
-				for (j = 0; j < n_field_components; j++) out[n_out++] = Ctrl->DATA.out_field[i*n_field_components+j];
-				GMT_output (GMT_stdout, n_out, out);
+			else {					/* DID CM4 and IGRF */
+				double x, y, z;
+				for (i = 0; i < T->segment[s]->n_rows; i++) {	/* Output the requested columns */
+					n_out = 0;
+					if (copy_input) for (j = 0; j < T->segment[s]->n_columns; j++) out[n_out++] = T->segment[s]->coord[j][i];
+					if (cm4_igrf_T) {
+						x = Ctrl->DATA.out_field[i*3  ] + igrf_xyz[i*3  ];
+						y = Ctrl->DATA.out_field[i*3+1] + igrf_xyz[i*3+1];
+						z = Ctrl->DATA.out_field[i*3+2] + igrf_xyz[i*3+2];
+						out[n_out++] = sqrt(x*x + y*y + z*z);
+					}
+					else {
+						for (j = 0; j < 3; j++)
+							out[n_out++] = Ctrl->DATA.out_field[i*3+j] + igrf_xyz[i*3+j];
+					}
+
+					GMT_output (GMT_stdout, n_out, out);
+				}
 			}
+
 		}
 		GMT_free_table (T);
 		if (fp != GMT_stdin) GMT_fclose (fp);
@@ -484,6 +566,7 @@ int main (int argc, char **argv) {
 	
 	GMT_free ((void *)Ctrl->DATA.out_field);
 	if (!(time_in_years || fixed_time)) GMT_free ((void *)time_years);
+	if (joint_IGRF_CM4) GMT_free ((void *)igrf_xyz);
 	
 	Free_CM4_Ctrl (Ctrl);	/* Deallocate control structure */
 	
