@@ -1,8 +1,8 @@
 /* -------------------------------------------------------------------
- *	$Id: mgd77sniffer.h,v 1.35 2009/01/09 04:02:35 guru Exp $	
- *      See COPYING file for copying and redistribution conditions.
+ *	$Id: mgd77sniffer.h,v 1.40 2010/03/22 18:55:47 guru Exp $	
+ *      See LICENSE.TXT file for copying and redistribution conditions.
  *
- *    Copyright (c) 2004-2009 by P. Wessel and M. T. Chandler
+ *    Copyright (c) 2004-2010 by P. Wessel and M. T. Chandler
  *	File:	mgd77sniffer.h
  *
  *	Include file for mgd77sniffer
@@ -96,7 +96,7 @@ struct MGD77_GRID_INFO {
 	struct GRD_HEADER grdhdr;
 	struct GMT_EDGEINFO edgeinfo;
 	struct GMT_BCR bcr;
-	int one_or_zero, nx, ny, col, sign, g_pts, format, mode, mx, interpolate;
+	int one_or_zero, nx, ny, col, sign, g_pts, format, mode, mx, interpolate, n_nan;
 	double scale, max_lat;
 	char abbrev[8];
 	char fname[32];
@@ -116,7 +116,8 @@ struct MGD77_SNIFFER_DEFAULTS {
 };
 
 struct MGD77_ERROR {
-	unsigned int flags[6];
+	unsigned int flags[N_ERROR_CLASSES];
+	int utc_offset;
 };
 
 struct MGD77_MAG_RF {
@@ -127,7 +128,7 @@ struct MGD77_MAG_RF {
 };
 
 /* Local functions */
-void read_grid (struct MGD77_GRID_INFO *info, float **grid, double w, double e, double s, double n, BOOLEAN bilinear, double threshold);
+void read_grid (struct MGD77_GRID_INFO *info, float **grid, double w, double e, double s, double n, GMT_LONG bilinear, double threshold);
 int sample_grid (struct MGD77_GRID_INFO *info, struct MGD77_DATA_RECORD *D, double **g, float *grid, GMT_LONG n_grid, GMT_LONG n);
 void regress_ls (double *x, double *y, GMT_LONG n, double *stat, int col);
 void regress_rls (double *x, double *y, GMT_LONG nvalues, double *stat, int col);
