@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77track.c,v 1.67 2009/07/10 22:10:23 remko Exp $
+ *	$Id: mgd77track.c,v 1.69 2010/03/22 18:55:47 guru Exp $
  *
- *    Copyright (c) 2004-2009 by P. Wessel
+ *    Copyright (c) 2004-2010 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -58,8 +58,8 @@ int main (int argc, char **argv)
 	int i, j, n_id = 0, mrk = 0, annot_name = 0, dist_flag = 2, use, n_paths;
 	int this_julian = 0, last_julian, argno, n_cruises = 0;
 	
-	BOOLEAN error = FALSE, first, both = FALSE, no_clip = FALSE;
-	BOOLEAN  annot_tick[2] = {0, 0}, draw_tick[2] = {0, 0}, dist_gap = FALSE, time_gap = FALSE;
+	GMT_LONG error = FALSE, first, both = FALSE, no_clip = FALSE;
+	GMT_LONG  annot_tick[2] = {0, 0}, draw_tick[2] = {0, 0}, dist_gap = FALSE, time_gap = FALSE;
 	
 	char *start_date = CNULL, *stop_date = CNULL, ms[GMT_TEXT_LEN], mc[GMT_TEXT_LEN];
        	char label[GMT_LONG_TEXT], date[GMT_TEXT_LEN], clock[GMT_TEXT_LEN], comment[BUFSIZ];
@@ -81,7 +81,7 @@ int main (int argc, char **argv)
 	int get_annotinfo (char *args, struct MGD77TRACK_ANNOT *info);
 	void annot_legname (double x, double y, double lon, double lat, double angle, char *text, double size);
 	double heading (GMT_LONG rec, double *lon, double *lat, GMT_LONG n_records);
-	BOOLEAN bad_coordinates (double lon, double lat);
+	GMT_LONG bad_coordinates (double lon, double lat);
 
 	argc = GMT_begin (argc, argv);		/* Initialize GMT Machinery */
 	
@@ -708,6 +708,6 @@ void annot_legname (double x, double y, double lon, double lat, double angle, ch
 	ps_text (x, y, size, text, angle, just, 0);
 }
 
-BOOLEAN bad_coordinates (double lon, double lat) {
+GMT_LONG bad_coordinates (double lon, double lat) {
 	return (GMT_is_dnan (lon) || GMT_is_dnan (lat));
 }
