@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: sphdistance.c,v 1.16 2009/07/11 03:16:31 guru Exp $
+ *	$Id: sphdistance.c,v 1.21 2010/03/22 18:55:47 guru Exp $
  *
- *	Copyright (c) 2008-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 2008-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -38,35 +38,35 @@
 
 struct SPHDISTANCE_CTRL {
 	struct C {	/* -C */
-		BOOLEAN active;
+		GMT_LONG active;
 	} C;
 	struct D {	/* -D */
-		BOOLEAN active;
+		GMT_LONG active;
 	} D;
 	struct E {	/* -E */
-		BOOLEAN active;
+		GMT_LONG active;
 	} E;
 	struct F {	/* -F */
-		BOOLEAN active;
+		GMT_LONG active;
 	} F;
 	struct G {	/* -G<maskfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct I {	/* -Idx[/dy] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double xinc, yinc;
 	} I;
 	struct L {	/* -L<unit>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		char unit;
 	} L;
 	struct N {	/* -N */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} N;
 	struct Q {	/* -Q */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} Q;
 };
@@ -79,7 +79,7 @@ int main (int argc, char **argv)
 	GMT_LONG ij, ii, s_row, n_row, w_col, e_col, side;
 	GMT_LONG n_expected_fields, n_args, n_fields, fno, n_files = 0, proj_type = 0;
 
-	BOOLEAN error = FALSE, nofile = TRUE, done = FALSE, first = FALSE;
+	GMT_LONG error = FALSE, nofile = TRUE, done = FALSE, first = FALSE;
 
 	double sx, sy, cx, cy, first_x = 0.0, first_y = 0.0, *in;
 	double *xx = NULL, *yy = NULL, *zz = NULL, *lon = NULL, *lat = NULL;
@@ -99,12 +99,12 @@ int main (int argc, char **argv)
 	struct GMT_LINE_SEGMENT *P = NULL;
 	struct GMT_TABLE *Table;
 	struct STRIPACK_VORONOI *V = NULL;
-	void *New_Sphdistance_Ctrl (), Free_Sphdistance_Ctrl (struct SPHDISTANCE_CTRL *C);
+	void *New_sphdistance_Ctrl (), Free_sphdistance_Ctrl (struct SPHDISTANCE_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct SPHDISTANCE_CTRL *)New_Sphdistance_Ctrl ();	/* Allocate and initialize a new control structure */
-	GMT_grd_init (&h, argc, argv, TRUE);
+	Ctrl = (struct SPHDISTANCE_CTRL *)New_sphdistance_Ctrl ();	/* Allocate and initialize a new control structure */
+	GMT_grd_init (&h, argc, argv, FALSE);
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -510,7 +510,7 @@ int main (int argc, char **argv)
 	
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Done!\n", GMT_program);
 
-	Free_Sphdistance_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_sphdistance_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -520,7 +520,7 @@ int main (int argc, char **argv)
 void prepare_polygon (struct GMT_LINE_SEGMENT *P)
 {
 	GMT_LONG i, quad_no, n_quad;
-	BOOLEAN quad[4] = {FALSE, FALSE, FALSE, FALSE};
+	GMT_LONG quad[4] = {FALSE, FALSE, FALSE, FALSE};
 	double lon_sum = 0.0, lat_sum = 0.0, lon, dlon;
 	double xmin1 = 360.0, xmin2 = 360.0, xmax1 = -360.0, xmax2 = -360.0;
 	
@@ -588,15 +588,15 @@ void prepare_polygon (struct GMT_LINE_SEGMENT *P)
 	}
 }
 
-void *New_Sphdistance_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_sphdistance_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct SPHDISTANCE_CTRL *C;
 	
-	C = (struct SPHDISTANCE_CTRL *) GMT_memory (VNULL, 1, sizeof (struct SPHDISTANCE_CTRL), "New_Sphdistance_Ctrl");
+	C = (struct SPHDISTANCE_CTRL *) GMT_memory (VNULL, 1, sizeof (struct SPHDISTANCE_CTRL), "New_sphdistance_Ctrl");
 	C->L.unit = 'E';	/* Default is meter distances */
 	return ((void *)C);
 }
 
-void Free_Sphdistance_Ctrl (struct SPHDISTANCE_CTRL *C) {	/* Deallocate control structure */
+void Free_sphdistance_Ctrl (struct SPHDISTANCE_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);	
 	if (C->Q.file) free ((void *)C->Q.file);	
 	GMT_free ((void *)C);	
