@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: sphtriangulate.c,v 1.14 2009/09/09 23:27:05 guru Exp $
+ *	$Id: sphtriangulate.c,v 1.21 2010/04/25 00:05:51 guru Exp $
  *
- *	Copyright (c) 2008-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 2008-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -33,60 +33,60 @@
 
 struct SPHTRIANGULATE_CTRL {
 	struct A {	/* -A */
-		BOOLEAN active;
+		GMT_LONG active;
 	} A;
 	struct C {	/* -C */
-		BOOLEAN active;
+		GMT_LONG active;
 	} C;
 	struct D {	/* -D */
-		BOOLEAN active;
+		GMT_LONG active;
 	} D;
 	struct G {	/* -G<output_grdfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} G;
 	struct L {	/* -L<unit>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		char unit;
 	} L;
 	struct N {	/* -N */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} N;
 	struct Q {	/* -Q */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;	/* 0 is Delaunay, 1 is Voronoi */
 	} Q;
 	struct T {	/* -T */
-		BOOLEAN active;
+		GMT_LONG active;
 	} T;
 };
 
-void stripack_voronoi_output (FILE *fp, GMT_LONG n, double *lon, double *lat, struct STRIPACK_VORONOI *V, BOOLEAN get_arcs, BOOLEAN get_area, BOOLEAN nodes, char *fname, double scl, PFD distfunc);
-void stripack_delaunay_output (FILE *fp, GMT_LONG n, double *lon, double *lat, struct STRIPACK_DELAUNAY *D, BOOLEAN get_arcs, BOOLEAN get_area, BOOLEAN nodes, char *fname, double scl, PFD distfunc);
-char *unit_name (char unit, BOOLEAN arc);
+void stripack_voronoi_output (FILE *fp, GMT_LONG n, double *lon, double *lat, struct STRIPACK_VORONOI *V, GMT_LONG get_arcs, GMT_LONG get_area, GMT_LONG nodes, char *fname, double scl, PFD distfunc);
+void stripack_delaunay_output (FILE *fp, GMT_LONG n, double *lon, double *lat, struct STRIPACK_DELAUNAY *D, GMT_LONG get_arcs, GMT_LONG get_area, GMT_LONG nodes, char *fname, double scl, PFD distfunc);
+char *unit_name (char unit, GMT_LONG arc);
 
 int main (int argc, char **argv)
 {
 	GMT_LONG i, n = 0, n_alloc, n_dup = 0;
 	GMT_LONG n_expected_fields, n_args, n_fields, proj_type = 0, fno, n_files = 0;
 
-	BOOLEAN error = FALSE, nofile = TRUE, done = FALSE, first = FALSE;
+	GMT_LONG error = FALSE, nofile = TRUE, done = FALSE, first = FALSE;
 
 	double sx, sy, cx, cy, first_x = 0.0, first_y = 0.0, d_scale, *in;
 	double *xx, *yy, *zz, *lon = NULL, *lat = NULL;
 
-	char line[BUFSIZ], *mode[2] = {"Delaunay", "Voronoi"}, *not_used = NULL;
+	char line[BUFSIZ], buffer[BUFSIZ], *mode[2] = {"Delaunay", "Voronoi"}, *not_used = NULL;
 	FILE *fp = NULL;
 	PFD distance_func;
 
 	struct SPHTRIANGULATE_CTRL *Ctrl;
 	struct STRIPACK T;
-	void *New_Sphtriangulate_Ctrl (), Free_Sphtriangulate_Ctrl (struct SPHTRIANGULATE_CTRL *C);
+	void *New_sphtriangulate_Ctrl (), Free_sphtriangulate_Ctrl (struct SPHTRIANGULATE_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct SPHTRIANGULATE_CTRL *)New_Sphtriangulate_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct SPHTRIANGULATE_CTRL *)New_sphtriangulate_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -323,11 +323,16 @@ int main (int argc, char **argv)
 	GMT_free ((void *) zz);
 	if (Ctrl->T.active) GMT_io.multi_segments[GMT_OUT] = TRUE;	/* Must produce multisegment output files */
 	if (!GMT_io.binary[GMT_OUT]) {
-		fprintf (GMT_stdout, "# sphtriangulate %s output via STRPACK.", mode[Ctrl->Q.mode]);
-		if (Ctrl->T.active)
-			fprintf (GMT_stdout, "  Arc lengths in %s\n", unit_name (Ctrl->L.unit, TRUE));
-		else
-			fprintf (GMT_stdout, "  Areas in %s\n", unit_name (Ctrl->L.unit, FALSE));
+		sprintf (buffer, "# sphtriangulate %s output via STRPACK.", mode[Ctrl->Q.mode]);
+		GMT_fputs (buffer, GMT_stdout);
+		if (Ctrl->T.active) {
+			sprintf (buffer, "  Arc lengths in %s\n", unit_name (Ctrl->L.unit, TRUE));
+			GMT_fputs (buffer, GMT_stdout);
+		}
+		else {
+			sprintf (buffer, "  Areas in %s\n", unit_name (Ctrl->L.unit, FALSE));
+			GMT_fputs (buffer, GMT_stdout);
+		}
 	}
 	if (Ctrl->Q.mode == VORONOI) {
 		stripack_voronoi_output (GMT_stdout, n, lon, lat, &T.V, Ctrl->T.active, Ctrl->A.active, Ctrl->N.active, Ctrl->N.file, d_scale, distance_func);
@@ -351,14 +356,14 @@ int main (int argc, char **argv)
 
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Done!\n", GMT_program);
 
-	Free_Sphtriangulate_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_sphtriangulate_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void stripack_delaunay_output (FILE *fp, GMT_LONG n, double *lon, double *lat, struct STRIPACK_DELAUNAY *D, BOOLEAN get_arcs, BOOLEAN get_area, BOOLEAN nodes, char *fname, double scl, PFD distfunc)
+void stripack_delaunay_output (FILE *fp, GMT_LONG n, double *lon, double *lat, struct STRIPACK_DELAUNAY *D, GMT_LONG get_arcs, GMT_LONG get_area, GMT_LONG nodes, char *fname, double scl, PFD distfunc)
 {	/* Prints out the Delaunay triangles either as polygons (for filling) or arcs (lines). */
 	GMT_LONG i, ij, k;
 	double out[4], area_sphere = 0.0, area_triangle = GMT_d_NaN, V[3][3], R2 = 6371007.1810 * 6371007.1810, dist = GMT_d_NaN;
@@ -387,8 +392,8 @@ void stripack_delaunay_output (FILE *fp, GMT_LONG n, double *lon, double *lat, s
 			if (nodes) {
 				out[GMT_X] = D->tri[ij];
 				out[GMT_Y] = D->tri[ij+1];
-				out[2] = D->tri[ij+2];
-				out[GMT_Y] = area_triangle * R2;
+				out[GMT_Z] = D->tri[ij+2];
+				out[3] = area_triangle * R2;
 				GMT_output (fp2, 4, out);
 				if (!GMT_io.binary[GMT_OUT]) sprintf (GMT_io.segment_header, "%c Triangle: %ld %d-%d-%d Area: %g\n", GMT_io.EOF_flag[GMT_OUT], k,
 					D->tri[ij], D->tri[ij+1], D->tri[ij+2], area_triangle * R2);
@@ -442,7 +447,7 @@ void stripack_delaunay_output (FILE *fp, GMT_LONG n, double *lon, double *lat, s
 	}
 }
 
-void stripack_voronoi_output (FILE *fp, GMT_LONG n, double *lon, double *lat, struct STRIPACK_VORONOI *V, BOOLEAN get_arcs, BOOLEAN get_area, BOOLEAN nodes, char *fname, double scl, PFD distfunc)
+void stripack_voronoi_output (FILE *fp, GMT_LONG n, double *lon, double *lat, struct STRIPACK_VORONOI *V, GMT_LONG get_arcs, GMT_LONG get_area, GMT_LONG nodes, char *fname, double scl, PFD distfunc)
 {	/* Prints out the Voronoi polygons either as polygons (for filling) or arcs (lines) */
 	GMT_LONG i, j, k, node, vertex, node_stop, node_new, vertex_new, node_last, vertex_last, n_arcs = 0;
 	GMT_LONG n_alloc = GMT_CHUNK, p_alloc = GMT_TINY_CHUNK;
@@ -514,7 +519,7 @@ void stripack_voronoi_output (FILE *fp, GMT_LONG n, double *lon, double *lat, st
 		} while (node_new != node_stop);
 
 		if (!get_arcs) {
-	    	if (get_area) area_km2 = area_polygon * R2;
+			if (get_area) area_km2 = area_polygon * R2;
 			if (nodes) {
 				out[GMT_X] = lon[node];
 				out[GMT_Y] = lat[node];
@@ -569,7 +574,7 @@ void stripack_voronoi_output (FILE *fp, GMT_LONG n, double *lon, double *lat, st
 	}
 }
 
-char *unit_name (char unit, BOOLEAN arc) {
+char *unit_name (char unit, GMT_LONG arc) {
 	char *name;
 	switch (unit) {
 		case 'K':	/* km */
@@ -590,16 +595,16 @@ char *unit_name (char unit, BOOLEAN arc) {
 	}
 	return (name);
 }
-void *New_Sphtriangulate_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_sphtriangulate_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct SPHTRIANGULATE_CTRL *C;
 	
-	C = (struct SPHTRIANGULATE_CTRL *) GMT_memory (VNULL, 1, sizeof (struct SPHTRIANGULATE_CTRL), "New_Sphtriangulate_Ctrl");
+	C = (struct SPHTRIANGULATE_CTRL *) GMT_memory (VNULL, 1, sizeof (struct SPHTRIANGULATE_CTRL), "New_sphtriangulate_Ctrl");
 	C->L.unit = 'E';	/* Default is meter distances */
 	
 	return ((void *)C);
 }
 
-void Free_Sphtriangulate_Ctrl (struct SPHTRIANGULATE_CTRL *C) {	/* Deallocate control structure */
+void Free_sphtriangulate_Ctrl (struct SPHTRIANGULATE_CTRL *C) {	/* Deallocate control structure */
 	if (C->G.file) free ((void *)C->G.file);	
 	if (C->N.file) free ((void *)C->N.file);	
 	GMT_free ((void *)C);	
