@@ -1,8 +1,8 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys.c,v 1.136 2009/07/11 03:16:32 guru Exp $
+ *	$Id: x2sys.c,v 1.145 2010/06/25 20:33:49 guru Exp $
  *
- *      Copyright (c) 1999-2009 by P. Wessel
- *      See COPYING file for copying and redistribution conditions.
+ *      Copyright (c) 1999-2010 by P. Wessel
+ *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -151,7 +151,7 @@ int x2sys_initialize (char *TAG, char *fname, struct GMT_IO *G,  struct X2SYS_IN
 	X->TAG = strdup (TAG);
 	X->info = (struct X2SYS_DATA_INFO *) GMT_memory (VNULL, n_alloc, sizeof (struct X2SYS_DATA_INFO), "x2sys_initialize");
 	X->file_type = X2SYS_ASCII;
-	X->x_col = X->y_col = X->t_col = -1;
+	X->x_col[GMT_IN] = X->y_col[GMT_IN] = X->t_col[GMT_IN] = -1;
 	X->ms_flag = '>';	/* Default multisegment header flag */
 	sprintf (line, "%s%c%s.def", TAG, DIR_DELIM, fname);
 	X->dist_flag = 0;	/* Cartesian distances */
@@ -212,9 +212,9 @@ int x2sys_initialize (char *TAG, char *fname, struct GMT_IO *G,  struct X2SYS_IN
 		c = (int)yes_no;
 		if (tolower (c) != 'Y') X->info[i].has_nan_proxy = TRUE;
 		if (!(X->info[i].scale == 1.0 && X->info[i].offset == 0.0)) X->info[i].do_scale = TRUE;
-		if (!strcmp (X->info[i].name, "x") || !strcmp (X->info[i].name, "lon"))  X->x_col = i;
-		if (!strcmp (X->info[i].name, "y") || !strcmp (X->info[i].name, "lat"))  X->y_col = i;
-		if (!strcmp (X->info[i].name, "t") || !strcmp (X->info[i].name, "time")) X->t_col = i;
+		if (!strcmp (X->info[i].name, "x") || !strcmp (X->info[i].name, "lon"))  X->x_col[GMT_IN] = i;
+		if (!strcmp (X->info[i].name, "y") || !strcmp (X->info[i].name, "lat"))  X->y_col[GMT_IN] = i;
+		if (!strcmp (X->info[i].name, "t") || !strcmp (X->info[i].name, "time")) X->t_col[GMT_IN] = i;
 		i++;
 		if (i == (int)n_alloc) {
 			n_alloc <<= 1;
@@ -238,8 +238,11 @@ int x2sys_initialize (char *TAG, char *fname, struct GMT_IO *G,  struct X2SYS_IN
 	for (i = 0; i < X->n_fields; i++) {	/* Default is same order and use all columns */
 		X->out_order[i] = i;
 		X->use_column[i] = 1;
-		G->in_col_type[i] = G->out_col_type[i] = (X->x_col == i) ? GMT_IS_LON : ((X->y_col == i) ? GMT_IS_LAT : GMT_IS_UNKNOWN);
+		G->in_col_type[i] = G->out_col_type[i] = (X->x_col[GMT_IN] == i) ? GMT_IS_LON : ((X->y_col[GMT_IN] == i) ? GMT_IS_LAT : GMT_IS_UNKNOWN);
 	}
+	X->x_col[GMT_OUT] = X->x_col[GMT_IN];
+	X->y_col[GMT_OUT] = X->y_col[GMT_IN];
+	X->t_col[GMT_OUT] = X->t_col[GMT_IN];
 	X->n_data_cols = x2sys_n_data_cols (X);
 	X->rec_size = (8 + X->n_data_cols) * sizeof (double);
 
@@ -293,9 +296,9 @@ int x2sys_n_data_cols (struct X2SYS_INFO *s)
 	int i, n = 0;
 
 	for (i = 0; i < s->n_out_columns; i++) {	/* Loop over all possible fields in this data set */
-		if (i == s->x_col) continue;
-		if (i == s->y_col) continue;
-		if (i == s->t_col) continue;
+		if (i == s->x_col[GMT_IN]) continue;
+		if (i == s->y_col[GMT_IN]) continue;
+		if (i == s->t_col[GMT_IN]) continue;
 		n++;	/* Only count data columns */
 	}
 
@@ -318,7 +321,6 @@ int x2sys_pick_fields (char *string, struct X2SYS_INFO *s)
 	strncpy (line, string, (size_t)BUFSIZ);	/* Make copy for later use */
 	memset ((void *)s->use_column, 0, (size_t)(s->n_fields * sizeof (int)));
 
-	s->x_col = s->y_col = s->t_col = -1;	/* Need to reset this to match data order */
 	while ((GMT_strtok (line, ",", &pos, p))) {
 		j = 0;
 		while (j < s->n_fields && strcmp (p, s->info[j].name)) j++;
@@ -326,9 +328,9 @@ int x2sys_pick_fields (char *string, struct X2SYS_INFO *s)
 			s->out_order[i] = j;
 			s->use_column[j] = 1;
 			/* Reset x,y,t indices */
-			if (!strcmp (s->info[j].name, "x") || !strcmp (s->info[j].name, "lon"))  s->x_col = i;
-			if (!strcmp (s->info[j].name, "y") || !strcmp (s->info[j].name, "lat"))  s->y_col = i;
-			if (!strcmp (s->info[j].name, "t") || !strcmp (s->info[j].name, "time")) s->t_col = i;
+			if (j == s->x_col[GMT_IN]) s->x_col[GMT_OUT] = i;
+			if (j == s->y_col[GMT_IN]) s->y_col[GMT_OUT] = i;
+			if (j == s->t_col[GMT_IN]) s->t_col[GMT_OUT] = i;
 		}
 		else {
 			fprintf (stderr, "X2SYS: ERROR: Unknown column name %s\n", p);
@@ -400,7 +402,7 @@ int x2sys_read_record (FILE *fp, double *data, struct X2SYS_INFO *s, struct GMT_
 {
 	int j, k, i, n_read = 0;
 	GMT_LONG pos;
-	BOOLEAN error = FALSE;
+	GMT_LONG error = FALSE;
 	char line[BUFSIZ], buffer[GMT_TEXT_LEN], p[BUFSIZ], c;
 	unsigned char u;
 	short int h;
@@ -494,7 +496,7 @@ int x2sys_read_record (FILE *fp, double *data, struct X2SYS_INFO *s, struct GMT_
 		else if (s->info[i].do_scale)
 			data[i] = data[i] * s->info[i].scale + s->info[i].offset;
 		if (GMT_is_dnan (data[i])) s->info[i].has_nans = TRUE;
-		if (i == s->x_col && s->geographic) GMT_lon_range_adjust (s->geodetic, &data[i]);
+		if (i == s->x_col[GMT_IN] && s->geographic) GMT_lon_range_adjust (s->geodetic, &data[i]);
 	}
 
 	return ((error || n_read != s->n_fields) ? -1 : 0);
@@ -502,15 +504,14 @@ int x2sys_read_record (FILE *fp, double *data, struct X2SYS_INFO *s, struct GMT_
  
 int x2sys_read_file (char *fname, double ***data, struct X2SYS_INFO *s, struct X2SYS_FILE_INFO *p, struct GMT_IO *G, GMT_LONG *n_rec)
 {
-	/* Reads the entire contents of the file given and returns the
-	 * number of data records.  The data matrix is return in the
-	 * pointer data.
+	/* Reads the the file given and returns the selected columns (or all)
+	 * from all data records.  The data matrix is return in the pointer data.
 	 */
 
 	GMT_LONG i, j;
 	size_t n_alloc;
 	FILE *fp;
-	double **z, *rec;
+	double **z, *field;
 	char path[BUFSIZ];
 
 	if (x2sys_get_data_path (path, fname, s->suffix)) {
@@ -525,29 +526,30 @@ int x2sys_read_file (char *fname, double ***data, struct X2SYS_INFO *s, struct X
 
 	n_alloc = GMT_CHUNK;
 
-	rec = (double *) GMT_memory (VNULL, (size_t)s->n_fields, sizeof (double), "x2sys_read_file");
-	z = (double **) GMT_memory (VNULL, (size_t)s->n_fields, sizeof (double *), "x2sys_read_file");
-	for (i = 0; i < s->n_fields; i++) z[i] = (double *) GMT_memory (VNULL, n_alloc, sizeof (double), "x2sys_read_file");
+	field = (double *) GMT_memory (VNULL, (size_t)s->n_fields, sizeof (double), "x2sys_read_file");
+	z = (double **) GMT_memory (VNULL, (size_t)s->n_out_columns, sizeof (double *), "x2sys_read_file");
+	for (i = 0; i < s->n_out_columns; i++) z[i] = (double *) GMT_memory (VNULL, n_alloc, sizeof (double), "x2sys_read_file");
 	p->ms_rec = (GMT_LONG *) GMT_memory (VNULL, n_alloc, sizeof (GMT_LONG), "x2sys_read_file");
 	x2sys_skip_header (fp, s);
 	p->n_segments = (s->multi_segment) ? -1 : 0;	/* So that first increment sets it to 0 */
 
 	j = 0;
-	while (!x2sys_read_record (fp, rec, s, G)) {	/* Gets the next data record */
-		for (i = 0; i < s->n_fields; i++) z[i][j] = rec[i];
+	while (!x2sys_read_record (fp, field, s, G)) {	/* Gets the next data record */
+		/* Only copy the requested fields */
+		for (i = 0; i < s->n_out_columns; i++) z[i][j] = field[s->out_order[i]];
 		if (s->multi_segment && s->ms_next) p->n_segments++;
 		p->ms_rec[j] = p->n_segments;
 		j++;
 		if (j == (GMT_LONG)n_alloc) {	/* Get more */
 			n_alloc <<= 1;
-			for (i = 0; i < s->n_fields; i++) z[i] = (double *) GMT_memory ((void *)z[i], n_alloc, sizeof (double), "x2sys_read_file");
+			for (i = 0; i < s->n_out_columns; i++) z[i] = (double *) GMT_memory ((void *)z[i], n_alloc, sizeof (double), "x2sys_read_file");
 			p->ms_rec = (GMT_LONG *) GMT_memory ((void *)p->ms_rec, n_alloc, sizeof (GMT_LONG), "x2sys_read_file");
 		}
 	}
 
 	fclose (fp);
-	GMT_free ((void *)rec);
-	for (i = 0; i < s->n_fields; i++) z[i] = (double *) GMT_memory ((void *)z[i], (size_t)j, sizeof (double), "x2sys_read_file");
+	GMT_free ((void *)field);
+	for (i = 0; i < s->n_out_columns; i++) z[i] = (double *) GMT_memory ((void *)z[i], (size_t)j, sizeof (double), "x2sys_read_file");
 	p->ms_rec = (GMT_LONG *) GMT_memory ((void *)p->ms_rec, (size_t)j, sizeof (GMT_LONG), "x2sys_read_file");
 
 	*data = z;
@@ -572,7 +574,7 @@ int x2sys_read_gmtfile (char *fname, double ***data, struct X2SYS_INFO *s, struc
 	GMT_LONG i, j;
 	char path[BUFSIZ];
 	FILE *fp;
-	double **z;
+	double **z, field[6];
 	double NaN, t_off;
 	struct GMTMGG_REC record;
 
@@ -606,7 +608,6 @@ int x2sys_read_gmtfile (char *fname, double ***data, struct X2SYS_INFO *s, struc
 	rata_day = GMT_rd_from_gymd (year, 1, 1);	/* Get the rata day for start of cruise year */
 	t_off = GMT_rdc2dt (rata_day, 0.0);		/* Secs to start of day */
 	
-	
 	if (fread ((void *)&n_records, sizeof (int), (size_t)1, fp) != 1) {
 		fprintf (stderr, "x2sys_read_gmtfile: Could not read n_records from %s\n", path);
 		return (GMT_GRDIO_READ_FAILED);
@@ -619,8 +620,8 @@ int x2sys_read_gmtfile (char *fname, double ***data, struct X2SYS_INFO *s, struc
 		return (GMT_GRDIO_READ_FAILED);
 	}
 
-	z = (double **) GMT_memory (VNULL, (size_t)6, sizeof (double *), "x2sys_read_gmtfile");
-	for (i = 0; i < 6; i++) z[i] = (double *) GMT_memory (VNULL, (size_t)p->n_rows, sizeof (double), "x2sys_read_gmtfile");
+	z = (double **) GMT_memory (VNULL, (size_t)s->n_out_columns, sizeof (double *), "x2sys_read_gmtfile");
+	for (i = 0; i < s->n_out_columns; i++) z[i] = (double *) GMT_memory (VNULL, (size_t)p->n_rows, sizeof (double), "x2sys_read_gmtfile");
 
 	for (j = 0; j < p->n_rows; j++) {
 
@@ -628,14 +629,15 @@ int x2sys_read_gmtfile (char *fname, double ***data, struct X2SYS_INFO *s, struc
 			fprintf (stderr, "x2sys_read_gmtfile: Could not read record %ld from %s\n", j, path);
 			return (GMT_GRDIO_READ_FAILED);
 		}
-
-		z[0][j] = record.time * gmtdefs.time_system.i_scale + t_off;	/* To get GMT time keeping */
-		z[1][j] = record.lat * MDEG2DEG;
-		z[2][j] = record.lon * MDEG2DEG;
-		z[3][j] = (record.gmt[0] == GMTMGG_NODATA) ? NaN : 0.1 * record.gmt[0];
-		z[4][j] = (record.gmt[1] == GMTMGG_NODATA) ? NaN : record.gmt[1];
-		z[5][j] = (record.gmt[2] == GMTMGG_NODATA) ? NaN : record.gmt[2];
-
+		/* Convert the 6 items to doubles */
+		field[0] = record.time * gmtdefs.time_system.i_scale + t_off;	/* To get GMT time keeping */
+		field[1] = record.lat * MDEG2DEG;
+		field[2] = record.lon * MDEG2DEG;
+		field[3] = (record.gmt[0] == GMTMGG_NODATA) ? NaN : 0.1 * record.gmt[0];
+		field[4] = (record.gmt[1] == GMTMGG_NODATA) ? NaN : record.gmt[1];
+		field[5] = (record.gmt[2] == GMTMGG_NODATA) ? NaN : record.gmt[2];
+		/* Only copy the requested fields */
+		for (i = 0; i < s->n_out_columns; i++) z[i][j] = field[s->out_order[i]];
 	}
 
 	fclose (fp);
@@ -780,7 +782,7 @@ int x2sys_read_mgd77ncfile (char *fname, double ***data, struct X2SYS_INFO *s, s
 
 int x2sys_read_ncfile (char *fname, double ***data, struct X2SYS_INFO *s, struct X2SYS_FILE_INFO *p, struct GMT_IO *G, GMT_LONG *n_rec)
 {
-	int i, n_fields, n_expect = BUFSIZ;
+	int i, n_fields, n_expect = GMT_MAX_COLUMNS;
 	size_t j;
 	char path[BUFSIZ];
 	double **z, *in;
@@ -836,8 +838,8 @@ int x2sys_xover_output (FILE *fp, int n, double out[])
 }
 
 int x2sys_read_list (char *file, char ***list, int *nf)
-{
-	int n_alloc = GMT_CHUNK, n = 0;
+{	/* Read a file with track names or track file names; strip off extensions */
+	int n_alloc = GMT_CHUNK, k, dot, n = 0;
 	char **p, line[BUFSIZ], name[GMT_TEXT_LEN];
 	FILE *fp;
 
@@ -850,8 +852,11 @@ int x2sys_read_list (char *file, char ***list, int *nf)
 	p = (char **) GMT_memory (VNULL, (size_t)n_alloc, sizeof (char *), "x2sys_read_list");
 
 	while (fgets (line, BUFSIZ, fp)) {
+		if (line[0] == '#' || line[0] == '>' || line[0] == '\0') continue;	/* Skip various comments and blank lines */
 		GMT_chop (line);	/* Remove trailing CR or LF */
 		sscanf (line, "%s", name);
+		for (k = strlen(name) - 1, dot = -1; dot == -1 && k >= 0; k--) if (name[k] == '.') dot = k;
+		if (dot > 0) name[dot] = '\0';	/* Chop off extension */
 		p[n] = strdup (name);
 		n++;
 		if (n == n_alloc) {
@@ -883,6 +888,7 @@ int x2sys_read_weights (char *file, char ***list, double **weights, int *nf)
 	W = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (double), "x2sys_read_weights");
 
 	while (fgets (line, BUFSIZ, fp)) {
+		if (line[0] == '#' || line[0] == '>' || line[0] == '\0') continue;	/* Skip various comments and blank lines */
 		GMT_chop (line);	/* Remove trailing CR or LF */
 		if (sscanf (line, "%s %lg", name, &this_w) != 2) {
 	 		fprintf (stderr, "x2sys_read_weights : Error parsing file %s near line %d\n", file, n);
@@ -922,7 +928,7 @@ int x2sys_set_system (char *TAG, struct X2SYS_INFO **S, struct X2SYS_BIX *B, str
 	int geodetic = 0, n, k, dist_flag = 0;
 	GMT_LONG pos = 0;
 	double dist;
-	BOOLEAN geographic = FALSE, n_given[2] = {FALSE, FALSE}, c_given = FALSE;
+	GMT_LONG geographic = FALSE, n_given[2] = {FALSE, FALSE}, c_given = FALSE;
 	FILE *fp;
 	struct X2SYS_INFO *s;
 	
@@ -1096,7 +1102,7 @@ int x2sys_set_system (char *TAG, struct X2SYS_INFO **S, struct X2SYS_BIX *B, str
 	return (X2SYS_NOERROR);
 }
 
-void x2sys_bix_init (struct X2SYS_BIX *B, BOOLEAN alloc)
+void x2sys_bix_init (struct X2SYS_BIX *B, GMT_LONG alloc)
 {
 	B->i_bin_x = 1.0 / B->bin_x;
 	B->i_bin_y = 1.0 / B->bin_y;
@@ -1152,6 +1158,7 @@ int x2sys_bix_read_tracks (struct X2SYS_INFO *S, struct X2SYS_BIX *B, int mode,
 
 	unused = fgets (line, BUFSIZ, ftrack);	/* Skip header record */
 	while (fgets (line, BUFSIZ, ftrack)) {
+		if (line[0] == '#' || line[0] == '>' || line[0] == '\0') continue;	/* Skip various comments and blank lines */
 		GMT_chop (line);	/* Remove trailing CR or LF */
 		sscanf (line, "%s %d %d", name, &id, &flag);
 		if (mode == 1) {
@@ -1181,7 +1188,7 @@ int x2sys_bix_read_tracks (struct X2SYS_INFO *S, struct X2SYS_BIX *B, int mode,
 	return (X2SYS_NOERROR);
 }
 
-int x2sys_bix_read_index (struct X2SYS_INFO *S, struct X2SYS_BIX *B, BOOLEAN swap)
+int x2sys_bix_read_index (struct X2SYS_INFO *S, struct X2SYS_BIX *B, GMT_LONG swap)
 {
 	/* Reads the binned index file which is native binary and thus swab is an issue */
 	char index_file[BUFSIZ], index_path[BUFSIZ];
@@ -1282,8 +1289,7 @@ void x2sys_path_init (struct X2SYS_INFO *S)
 	}
 
 	while (fgets (line, BUFSIZ, fp) && n_x2sys_paths < MAX_DATA_PATHS) {
-		if (line[0] == '#') continue;	/* Comments */
-		if (line[0] == ' ' || line[0] == '\0') continue;	/* Blank line */
+		if (line[0] == '#' || line[0] == '>' || line[0] == '\0') continue;	/* Skip various comments and blank lines */
 		GMT_chop (line);	/* Remove trailing CR or LF */
 		x2sys_datadir[n_x2sys_paths] = GMT_memory (VNULL, (size_t)1, (size_t)(strlen (line)+1), "x2sys_path_init");
 #if _WIN32
@@ -1305,8 +1311,8 @@ void x2sys_path_init (struct X2SYS_INFO *S)
 int x2sys_get_data_path (char *track_path, char *track, char *suffix)
 {
 	int id;
-	BOOLEAN add_suffix;
-	char geo_path[BUFSIZ];
+	GMT_LONG add_suffix = FALSE;
+	char geo_path[BUFSIZ], dotsuffix[GMT_TEXT_LEN];
 
 	if (track[0] == '/' || track[1] == ':') {	/* Full path given, just return it */
 		strcpy(track_path, track);
@@ -1315,7 +1321,8 @@ int x2sys_get_data_path (char *track_path, char *track, char *suffix)
 	
 	/* Check if we need to append suffix */
 	
-	add_suffix = strncmp (&track[strlen(track)-strlen(suffix)], suffix, strlen(suffix));	/* Need to add suffix? */
+	sprintf (dotsuffix, ".%s", suffix);
+	add_suffix = strncmp (&track[strlen(track)-strlen(dotsuffix)], dotsuffix, strlen(dotsuffix));	/* Need to add suffix? */
 
 	/* First look in current directory */
 
@@ -1414,7 +1421,7 @@ GMT_LONG x2sys_read_coe_dbase (struct X2SYS_INFO *S, char *dbase, char *ignorefi
 	char stop[2][GMT_TEXT_LEN], info[2][3*GMT_TEXT_LEN], **trk_list, **ignore = NULL, *t = NULL;
 	GMT_LONG p, n_pairs;
 	int i, k, n_alloc_x, n_alloc_p, n_alloc_t, year[2], id[2], n_ignore = 0, n_tracks = 0, n_items, our_item = -1;
-	BOOLEAN more, skip, two_values = FALSE, check_box, keep = TRUE, no_time = FALSE;
+	GMT_LONG more, skip, two_values = FALSE, check_box, keep = TRUE, no_time = FALSE;
 	double x, m, lon, dist[2], d_val;
 
 	fp = stdin;	/* Default to stdin if dbase is NULL */
@@ -1664,7 +1671,7 @@ int x2sys_find_track (char *name, char **list, int n)
 	return (-1);
 }
 
-int x2sys_get_tracknames (int argc, char **argv, char ***filelist, BOOLEAN *cmdline)
+int x2sys_get_tracknames (int argc, char **argv, char ***filelist, GMT_LONG *cmdline)
 {	/* Return list of track names given on command line or via =list mechanism.
 	 * The names do not have the track extension. */
 	int i, A, list = 0, add_chunk, n_alloc;
