@@ -1,8 +1,8 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_put.c,v 1.39 2009/07/11 03:16:32 guru Exp $
+ *	$Id: x2sys_put.c,v 1.42 2010/03/22 18:55:47 guru Exp $
  *
- *      Copyright (c) 1999-2009 by P. Wessel
- *      See COPYING file for copying and redistribution conditions.
+ *      Copyright (c) 1999-2010 by P. Wessel
+ *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@ int main (int argc, char **argv)
 	char track_file[BUFSIZ], index_file[BUFSIZ], old_track_file[BUFSIZ], old_index_file[BUFSIZ];
 	char track_path[BUFSIZ], index_path[BUFSIZ], old_track_path[BUFSIZ], old_index_path[BUFSIZ];
 
-	BOOLEAN error = FALSE, replace = FALSE, delete = FALSE, found_it, skip, swap = FALSE;
+	GMT_LONG error = FALSE, replace = FALSE, delete = FALSE, found_it, skip, swap = FALSE;
 
 	FILE *fp = NULL, *fbin, *ftrack;
 
@@ -54,7 +54,7 @@ int main (int argc, char **argv)
 	size_t s_unused = 0;
 
 	int x2sys_bix_remove_track (int track_id, struct X2SYS_BIX *B);
-	struct X2SYS_BIX_TRACK_INFO * x2sys_bix_find_track (char *track, BOOLEAN *found_it, struct X2SYS_BIX *B);
+	struct X2SYS_BIX_TRACK_INFO * x2sys_bix_find_track (char *track, GMT_LONG *found_it, struct X2SYS_BIX *B);
 
 	argc = GMT_begin (argc, argv);
 	
@@ -313,7 +313,7 @@ int x2sys_bix_remove_track (int track_id, struct X2SYS_BIX *B)
 	return (track_id);
 }
 
-struct X2SYS_BIX_TRACK_INFO * x2sys_bix_find_track (char *track, BOOLEAN *found_it, struct X2SYS_BIX *B)
+struct X2SYS_BIX_TRACK_INFO * x2sys_bix_find_track (char *track, GMT_LONG *found_it, struct X2SYS_BIX *B)
 {	/* Looks for given track in data base and if found returns pointer to the track before it and sets found_it to TRUE.
 	 * I.e., the track is actually this_info->next_info.  If not found set found_it to FALSE and return pointer where
 	 * this track should be inserted */
