@@ -1,8 +1,8 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_solve.c,v 1.35 2009/07/11 03:16:32 guru Exp $
+ *	$Id: x2sys_solve.c,v 1.44 2010/03/25 00:58:56 jluis Exp $
  *
- *      Copyright (c) 1999-2009 by P. Wessel
- *      See COPYING file for copying and redistribution conditions.
+ *      Copyright (c) 1999-2010 by P. Wessel
+ *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -121,36 +121,29 @@ double basis_z (double **P, int which, int col) {	/* Basis function f for a depe
 	return (P[COL_Z1+which][col]);
 }
 
-#ifdef SAVEFORLATER
-int x2sys_read_namedatelist (char *file, char ***list, double **start, int *nf);
-#endif
-
 int main (int argc, char **argv)
 {
 	char *TAG = CNULL, *column = CNULL, **trk_list = NULL, *dbase = CNULL;
 	char  trk[2][GMT_TEXT_LEN], t_txt[2][GMT_TEXT_LEN], z_txt[GMT_TEXT_LEN], w_txt[GMT_TEXT_LEN], line[BUFSIZ];
-#ifdef SAVEFORLATER
-	char *tracklist = CNULL;
-#endif
-	BOOLEAN error = FALSE, grow_list = FALSE, normalize = FALSE, use_weights = FALSE, active_col[N_COE_PARS];
-	int n_par = 0, n, m, *ID[2];
-	int t, n_tracks = 0, mode = 0, n_active;
+	GMT_LONG error = FALSE, grow_list = FALSE, normalize = FALSE, use_weights = FALSE, active_col[N_COE_PARS], reset_zero = FALSE;
+	GMT_LONG write_mat_eq = FALSE, scale_range = FALSE;
+	int *ID[2];
+	int	it, n_iterations = 1;
+	GMT_LONG n_par = 0, n, m, t, n_tracks = 0, mode = 0, n_active;
 	GMT_LONG i, p, j, k, r, s, off, row, n_COE = 0, n_alloc = GMT_CHUNK, n_alloc_t = GMT_CHUNK, ierror;
 	double *N, *a, *b, *data[N_COE_PARS], sgn, zero_test = 1.0e-08, old_mean, new_mean, sw2;
-	double old_stdev, new_stdev, e_k, min_extent, max_extent, range = 0.0, Sw, Sx, Sxx;
-#ifdef SAVEFORLATER
-	double *start = NULL;
-#endif
+	double old_stdev, new_stdev, e_k, Sw, Sx, Sxx, range = 0.0, *start = NULL;
+	double sc_range = 1;
 	struct X2SYS_INFO *S;
 	struct X2SYS_BIX B;
 	FILE *fp;
 	PFD basis[N_BASIS];
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 	
 	for (i = strlen(argv[0]); i >= 0 && argv[0][i] != '/'; i--);
 	X2SYS_program = &argv[0][i+1];	/* Name without full path */
-	memset ((void *)active_col, FALSE, N_COE_PARS * sizeof (BOOLEAN));
+	memset ((void *)active_col, FALSE, N_COE_PARS * sizeof (GMT_LONG));
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -185,17 +178,22 @@ int main (int argc, char **argv)
 							break;
 					}
 					break;
-#ifdef SAVEFORLATER
-				case 'I':	/* List of track names and their start time dateTclock */
-					tracklist = &argv[i][2];
+				case 'M':
+					write_mat_eq = TRUE;
+					break;
+				case 'S':
+					scale_range = TRUE;
+					sc_range = atof(&argv[i][2]);
 					break;
-#endif
 				case 'T':
 					TAG = &argv[i][2];
 					break;
 				case 'W':
 					use_weights = TRUE;
 					break;
+				case 'Z':
+					reset_zero = TRUE;
+					break;
 				default:
 					error = TRUE;
 					fprintf (stderr, "%s: Unrecognized option -%c\n", GMT_program, argv[i][1]);
@@ -208,11 +206,7 @@ int main (int argc, char **argv)
 
 	if (argc == 1 || error || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "x2sys_solve %s - Determine least-squares systematic correction from crossovers\n\n", X2SYS_VERSION);
-#ifdef SAVEFORLATER
-		fprintf (stderr, "usage: x2sys_solve -C<column> -E<flag> -T<TAG> [<coedata>] [-I<tracklist>] [-V] [%s]\n\n", GMT_bi_OPT);
-#else
-		fprintf (stderr, "usage: x2sys_solve -C<column> -E<flag> -T<TAG> [<coedata>] [-V] [%s]\n\n", GMT_bi_OPT);
-#endif
+		fprintf (stderr, "usage: x2sys_solve -C<column> -E<flag> -T<TAG> [<coedata>] [-V] [-W] [Z] [%s]\n\n", GMT_bi_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -222,11 +216,9 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-T <TAG> is the x2sys tag for the data set.\n");
 		fprintf (stderr, "\n\tOPTIONS:\n");
 		fprintf (stderr, "\t<coedata> is the ASCII data output file from x2sys_list [or we read stdin]\n");
-#ifdef SAVEFORLATER
-		fprintf (stderr, "\t-I List of tracks and their start date (required for -Et)\n");
-#endif
 		GMT_explain_option ('V');
 		fprintf (stderr, "\t-W weights are present in last column for weighted fit [no weights]\n");
+		fprintf (stderr, "\t-Z Use the earliest time and shortest distance as local origin [use 0].\n");
 		GMT_explain_option ('i');
 		exit (EXIT_FAILURE);
 	}
@@ -235,17 +227,6 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: ERROR -E: Choose among c, d, g, h, s and t\n", GMT_program);
 		exit (EXIT_FAILURE);
 	}
-#ifdef SAVEFORLATER
-	if (mode == F_IS_DRIFT_T && !tracklist) {
-		fprintf (stderr, "%s: ERROR -Ed: Solution requires -I<tracklist>\n", GMT_program);
-		exit (EXIT_FAILURE);
-	}
-	
-	if (tracklist && x2sys_read_namedatelist (tracklist, &trk_list, &start, &n_tracks) == X2SYS_NOERROR) {
-		fprintf (stderr, "%s: ERROR -I: Problems reading %s\n", GMT_program, tracklist);
-		exit (EXIT_FAILURE);	
-	}
-#endif
 	
 	/* Initialize system via the tag */
 	
@@ -305,6 +286,7 @@ int main (int argc, char **argv)
 		data[i] = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (double), GMT_program);
 		n_active++;
 	}
+	data[COL_WW] = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (double), GMT_program);
 	for (i = 0; i < 2; i++) ID[i] = (int *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (int), GMT_program);
 	
 	/* Read the crossover info */
@@ -323,7 +305,8 @@ int main (int argc, char **argv)
 	n_COE = 0;
 	if (GMT_io.binary[GMT_IN]) {	/* Binary input */
 		/* Here, first two cols have track IDs and we do not write track names */
-		int min_ID, max_ID, n_fields, n_tracks2, n_expected_fields;
+		int min_ID, max_ID;
+		GMT_LONG n_fields, n_tracks2, n_expected_fields;
 		double *in;
 		char *check;
 		
@@ -373,6 +356,7 @@ int main (int argc, char **argv)
 			if (n_COE == n_alloc) {
 				n_alloc <<= 1;
 				for (i = 0; i < N_COE_PARS; i++) if (active_col[i]) data[i] = (double *) GMT_memory ((void *)data[i], (size_t)n_alloc, sizeof (double), GMT_program);
+				data[COL_WW] = (double *) GMT_memory ((void *)data[COL_WW], (size_t)n_alloc, sizeof (double), GMT_program);
 			}
 		}
 		/* Check that IDs are all contained within 0 <= ID < n_tracks and that there are no gaps */
@@ -395,6 +379,7 @@ int main (int argc, char **argv)
 		}
 		if (error) {	/* Delayed the cleanup until here */
 			for (i = 0; i < N_COE_PARS; i++) if (active_col[i]) GMT_free ((void *)data[i]);
+			GMT_free ((void *)data[COL_WW]);
 			for (i = 0; i < 2; i++) GMT_free ((void *)ID[i]);
 			exit (EXIT_FAILURE);
 		}
@@ -408,39 +393,54 @@ int main (int argc, char **argv)
 			exit (EXIT_FAILURE);	
 		}
 		while (GMT_fgets (line, BUFSIZ, fp)) {    /* Not yet EOF */
+			GMT_chop (line);					/* Rid the world of CR/LF */
 			if (line[0] == '#') continue;	/* Skip other comments */
 			switch (mode) {	/* Handle input differently depending on what is expected */
 				case F_IS_CONSTANT:
 					sscanf (line, "%s %s %s %s", trk[0], trk[1], z_txt, w_txt);
-					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) data[COL_COE][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) 
+						data[COL_COE][n_COE] = GMT_d_NaN;
 					break;
 				case F_IS_DRIFT_T:
 					sscanf (line, "%s %s %s %s %s %s", trk[0], trk[1], t_txt[0], t_txt[1], z_txt, w_txt);
-					if (GMT_scanf (t_txt[0], GMT_IS_ABSTIME, &data[COL_T1][n_COE]) == GMT_IS_NAN) data[COL_T1][n_COE] = GMT_d_NaN;
-					if (GMT_scanf (t_txt[1], GMT_IS_ABSTIME, &data[COL_T2][n_COE]) == GMT_IS_NAN) data[COL_T2][n_COE] = GMT_d_NaN;
-					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) data[COL_COE][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (t_txt[0], GMT_IS_ABSTIME, &data[COL_T1][n_COE]) == GMT_IS_NAN) 
+						data[COL_T1][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (t_txt[1], GMT_IS_ABSTIME, &data[COL_T2][n_COE]) == GMT_IS_NAN) 
+						data[COL_T2][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) 
+						data[COL_COE][n_COE] = GMT_d_NaN;
 					break;
 				case F_IS_DRIFT_D:
 					sscanf (line, "%s %s %s %s %s %s", trk[0], trk[1], t_txt[0], t_txt[1], z_txt, w_txt);
-					if (GMT_scanf (t_txt[0], GMT_IS_FLOAT, &data[COL_D1][n_COE]) == GMT_IS_NAN) data[COL_D1][n_COE] = GMT_d_NaN;
-					if (GMT_scanf (t_txt[1], GMT_IS_FLOAT, &data[COL_D2][n_COE]) == GMT_IS_NAN) data[COL_D2][n_COE] = GMT_d_NaN;
-					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) data[COL_COE][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (t_txt[0], GMT_IS_FLOAT, &data[COL_D1][n_COE]) == GMT_IS_NAN) 
+						data[COL_D1][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (t_txt[1], GMT_IS_FLOAT, &data[COL_D2][n_COE]) == GMT_IS_NAN) 
+						data[COL_D2][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) 
+						data[COL_COE][n_COE] = GMT_d_NaN;
 					break;
 				case F_IS_GRAV1930:
 					sscanf (line, "%s %s %s %s %s", trk[0], trk[1], t_txt[0], z_txt, w_txt);
-					if (GMT_scanf (t_txt[0], GMT_IS_LAT, &data[COL_YY][n_COE]) == GMT_IS_NAN) data[COL_YY][n_COE] = GMT_d_NaN;
-					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) data[COL_COE][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (t_txt[0], GMT_IS_LAT, &data[COL_YY][n_COE]) == GMT_IS_NAN) 
+						data[COL_YY][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) 
+						data[COL_COE][n_COE] = GMT_d_NaN;
 					break;
 				case F_IS_HEADING:
 					sscanf (line, "%s %s %s %s %s %s", trk[0], trk[1], t_txt[0], t_txt[1], z_txt, w_txt);
-					if (GMT_scanf (t_txt[0], GMT_IS_FLOAT, &data[COL_H1][n_COE]) == GMT_IS_NAN) data[COL_H1][n_COE] = GMT_d_NaN;
-					if (GMT_scanf (t_txt[1], GMT_IS_FLOAT, &data[COL_H2][n_COE]) == GMT_IS_NAN) data[COL_H2][n_COE] = GMT_d_NaN;
-					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) data[COL_COE][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (t_txt[0], GMT_IS_FLOAT, &data[COL_H1][n_COE]) == GMT_IS_NAN) 
+						data[COL_H1][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (t_txt[1], GMT_IS_FLOAT, &data[COL_H2][n_COE]) == GMT_IS_NAN) 
+						data[COL_H2][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (z_txt, GMT_IS_FLOAT, &data[COL_COE][n_COE]) == GMT_IS_NAN) 
+						data[COL_COE][n_COE] = GMT_d_NaN;
 					break;
 				case F_IS_SCALE:
 					sscanf (line, "%s %s %s %s %s", trk[0], trk[1], t_txt[0], t_txt[1], w_txt);
-					if (GMT_scanf (t_txt[0], GMT_IS_FLOAT, &data[COL_Z1][n_COE]) == GMT_IS_NAN) data[COL_Z1][n_COE] = GMT_d_NaN;
-					if (GMT_scanf (t_txt[1], GMT_IS_FLOAT, &data[COL_Z2][n_COE]) == GMT_IS_NAN) data[COL_Z2][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (t_txt[0], GMT_IS_FLOAT, &data[COL_Z1][n_COE]) == GMT_IS_NAN) 
+						data[COL_Z1][n_COE] = GMT_d_NaN;
+					if (GMT_scanf (t_txt[1], GMT_IS_FLOAT, &data[COL_Z2][n_COE]) == GMT_IS_NAN) 
+						data[COL_Z2][n_COE] = GMT_d_NaN;
 					break;
 			}
 			if (use_weights) {
@@ -454,51 +454,62 @@ int main (int argc, char **argv)
 			}
 			
 			for (i = 0; i < 2; i++) {	/* Look up track IDs */
-				ID[i][n_COE] = x2sys_find_track (trk[i], trk_list, n_tracks);	/* Return track id # for this leg */
+				ID[i][n_COE] = x2sys_find_track (trk[i], trk_list, (int)n_tracks);	/* Return track id # for this leg */
 				if (ID[i][n_COE] == -1) {	/* Leg not in the data base yet */
 					if (grow_list) {	/* Add it */
 						trk_list[n_tracks] = strdup (trk[i]);
-						ID[i][n_COE] = n_tracks++;
+						ID[i][n_COE] = (int)n_tracks++;
 						if (n_tracks == n_alloc_t) {
 							n_alloc_t <<= 1;
 							trk_list = (char **) GMT_memory ((void *)trk_list, (size_t)n_alloc_t, sizeof (char *), GMT_program);
 						}
 					}
-#ifdef SAVEFORLATER
-					else {
-						fprintf (stderr, "%s: ERROR: Track %s not in specified list of tracks [%s]\n", GMT_program, trk[i], tracklist);
-						exit (EXIT_FAILURE);					
-					}
-#endif
 				}
 			}
 		
 			n_COE++;
 			if (n_COE == n_alloc) {
 				n_alloc <<= 1;
-				for (i = 0; i < N_COE_PARS; i++) if (active_col[i]) data[i] = (double *) GMT_memory ((void *)data[i], (size_t)n_alloc, sizeof (double), GMT_program);
-				for (i = 0; i < 2; i++) ID[i] = (int *) GMT_memory ((void *)ID[i], (size_t)n_alloc, sizeof (int), GMT_program);
+				for (i = 0; i < N_COE_PARS; i++) 
+					if (active_col[i]) 
+						data[i] = (double *) GMT_memory ((void *)data[i], (size_t)n_alloc, sizeof (double), GMT_program);
+				data[COL_WW] = (double *) GMT_memory ((void *)data[COL_WW], (size_t)n_alloc, sizeof (double), GMT_program);
+				for (i = 0; i < 2; i++) 
+					ID[i] = (int *) GMT_memory ((void *)ID[i], (size_t)n_alloc, sizeof (int), GMT_program);
 			}
 		}
 	}
 	if (fp != GMT_stdin) GMT_fclose(fp);
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Found %ld COE records\n", GMT_program, n_COE);
-	for (i = 0; i < N_COE_PARS; i++) if (active_col[i]) data[i] = (double *) GMT_memory ((void *)data[i], (size_t)n_COE, sizeof (double), GMT_program);
+	for (i = 0; i < N_COE_PARS; i++) 
+		if (active_col[i]) data[i] = (double *) GMT_memory ((void *)data[i], (size_t)n_COE, sizeof (double), GMT_program);
+	data[COL_WW] = (double *) GMT_memory ((void *)data[COL_WW], (size_t)n_COE, sizeof (double), GMT_program);
 	
 	normalize = (mode == F_IS_DRIFT_T || mode == F_IS_DRIFT_D);
 	if (normalize) {	/* For numerical stability, normalize distances or times to fall in 0-1 range */
-		min_extent = DBL_MAX;	max_extent = -DBL_MAX;
+		double min_extent, max_extent;
+		start = (double *) GMT_memory (NULL, (size_t)n_tracks, sizeof (double), GMT_program);
 		j = (mode == F_IS_DRIFT_T) ? COL_T1 : COL_D1;	/* Which variable we are working on */
+		
+		if (reset_zero) {	/* Must determine smallest t or d for all tracks */
+			for (k = 0; k < n_tracks; k++) start[k] = DBL_MAX;
+			for (k = 0; k < n_COE; k++) {
+				for (i = 0; i < 2; i++) {
+					if (data[j+i][k] < start[ID[i][k]]) start[ID[i][k]] = data[j+i][k];
+				}
+			}
+		}
+		/* Now we know the start time/distance [or all 0].  Remove it to reduce mangitudes of values */
+		min_extent = DBL_MAX;	max_extent = -DBL_MAX;
 		for (k = 0; k < n_COE; k++) {
 			for (i = 0; i < 2; i++) {
-#ifdef SAVEFORLATER
-				if (mode == F_IS_DRIFT_T) data[COL_T1+i][k] -= start[ID[i][k]];	/* Remove origin time for track */
-#endif
+				if (reset_zero) data[j+i][k] -= start[ID[i][k]];
 				if (data[j+i][k] < min_extent) min_extent = data[j+i][k];
 				if (data[j+i][k] > max_extent) max_extent = data[j+i][k];
 			}
 		}
 		range = max_extent - min_extent;
+		if (scale_range) range /= sc_range;
 		for (k = 0; k < n_COE; k++) for (i = 0; i < 2; i++) data[j+i][k] /= range;
 	}
 	
@@ -522,7 +533,13 @@ int main (int argc, char **argv)
 	/* Build A'A and A'b ==> N*x = b normal equation matrices directly since A may be too big to do A'A by multiplication.
 	 * For all corrections that involve a constant shift we must add the constraint that such shifts sum to zero; this
 	 * is implemented by adding an extra row/column with the appropriate 0s and 1s and a Lagrange multiplier. */
-	
+
+	for (it = 0; it < n_iterations; it++) {
+		if (it > 0) {
+			memset((void *)N, 0, m*m*sizeof(double));
+			memset((void *)b, 0, m*sizeof(double));
+		}
+
 	for (p = row = 0; p < n_tracks; p++) {	/* For each track */
 		for (s = 0; s < n_par; s++, row++) {	/* For each track's unknown parameter  */
 			for (k = 0; k < n_COE; k++) {	/* For each crossover */
@@ -543,22 +560,40 @@ int main (int argc, char **argv)
 			if (mode != F_IS_SCALE && s == 0) N[m*row+m-1] = 1.0;	/* Augmented column entry for Lagrange multiplier */
 		}
 	}
+
 	if (mode != F_IS_SCALE) {	/* Augmented row for Lagrange multiplier for constants */
 		for (i = 0, off = m*n; i < n; i += n_par) N[off+i] = 1.0;
 	}
 	
 #ifdef DEBUGX	
-	fprintf (stderr, "Matrix equation N * a = b:\n");
+	fprintf (stderr, "Matrix equation N * a = b: (N = %ld)\n", m);
 	for (i = 0; i < m; i++) {
 		for (j = 0; j < m; j++) fprintf (stderr, "%8.2f\t", N[i*m+j]);
 		fprintf (stderr, "\t%8.2f\n", b[i]);
 	}
 #endif
 
+	if (write_mat_eq) {
+		char *Na, *B;
+		FILE *fp;
+		Na = "Na.dat";		B = "b.dat";
+		fp = fopen(Na, "w");
+		for (i = 0; i < m; i++) {
+			for (j = 0; j < m; j++) fprintf (fp, "%f\t", N[i*m+j]);
+			fprintf (fp, "\n");
+		}
+		fclose(fp);
+
+		fp = fopen(B, "w");
+		for (i = 0; i < m; i++)
+			fprintf (fp, "%f\n", b[i]);
+		fclose(fp);
+	}
+
 	/* Get LS solution */
 
 	GMT_gauss (N, b, m, m, zero_test, &ierror, 1);
-	GMT_free ((void *)N);
+	if (it == n_iterations-1) GMT_free ((void *)N);
 	a = b;	/* Convenience since the solution is called a in the notes */
 
 	/* Estimate new st.dev. */
@@ -576,11 +611,26 @@ int main (int argc, char **argv)
 #ifdef DEBUGX	
 		fprintf (stderr, "COE # %ld: Was %g Is %g\n", k, data[COL_COE][k], e_k);
 #endif
+		if (it > 0) {
+			data[COL_COE][k] = e_k;
+		}
 	}
 	new_mean = Sx / Sw;
 	new_stdev = sqrt ((n_COE * Sxx - Sx * Sx) / (Sw*Sw*(n_COE - 1.0)/n_COE));
 	
-	if (gmtdefs.verbose) fprintf (stderr, "%s: Old mean and st.dev.: %g %g New mean and st.dev.: %g %g\n", GMT_program, old_mean, old_stdev, new_mean, new_stdev);
+		if (gmtdefs.verbose)
+			fprintf (stderr, "%s: Iteration %d:\tOld mean and st.dev.: %g %g New mean and st.dev.: %g %g\n", 
+				GMT_program, it+1, old_mean, old_stdev, new_mean, new_stdev);
+
+		old_mean  = new_mean;
+		old_stdev = new_stdev;
+
+		if (it > 0) {
+			for (p = 0; p < n_tracks; p++)		/* For each track */ 
+				for (r = 0; r < n_par; r++) 	/* For each track's parameter in f(p)  */
+					a[p*n_par + r] += a[p*n_par + r];
+		}
+	}	/* end iteration loop */
 	
 	/* Write correction table */
 	
@@ -593,10 +643,16 @@ int main (int argc, char **argv)
 				printf ("\t%g\n", a[p]);
 				break;
 			case F_IS_DRIFT_T:
-				printf ("\t%g\t%g*((time-T))\n", a[p*n_par], a[p*n_par+1]);
+				if (reset_zero)
+					printf ("\t%g\t%g*((time-T))\n", a[p*n_par], a[p*n_par+1]);
+				else
+					printf ("\t%g\t%g*((time-%g))\n", a[p*n_par], a[p*n_par+1], start[p]);
 				break;
 			case F_IS_DRIFT_D:
-				printf ("\t%g\t%g*((dist))\n", a[p*n_par], a[p*n_par+1]);
+				if (reset_zero)
+					printf ("\t%g\t%g*((dist-%g))\n", a[p*n_par], a[p*n_par+1], start[p]);
+				else
+					printf ("\t%g\t%g*((dist))\n", a[p*n_par], a[p*n_par+1]);
 				break;
 			case F_IS_GRAV1930:
 				printf ("\t%g\t%g*sin((lat))^2\n", a[p*n_par], a[p*n_par+1]);
@@ -613,59 +669,14 @@ int main (int argc, char **argv)
 	/* Free up memory */
 	
 	for (i = 0; i < N_COE_PARS; i++) if (active_col[i]) GMT_free ((void *)data[i]);
+	GMT_free ((void *)data[COL_WW]);
 	for (i = 0; i < 2; i++) GMT_free ((void *)ID[i]);
 	GMT_free ((void *)b);
-	x2sys_free_list (trk_list, n_tracks);
-#ifdef SAVEFORLATER
-	if (start) GMT_free ((void *)start);
-#endif
+	if (reset_zero) GMT_free ((void *)start);
+	x2sys_free_list (trk_list, (int)n_tracks);
 
 	x2sys_end (S);
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
-
-#ifdef SAVEFORLATER
-int x2sys_read_namedatelist (char *file, char ***list, double **start, int *nf)
-{
-	/* Reads a list with track names and their origin times (needed for -Et) */
-	int n_alloc = GMT_CHUNK, n = 0;
-	char **p, line[BUFSIZ], name[GMT_TEXT_LEN], date[GMT_TEXT_LEN];
-	double *T;
-	FILE *fp;
-
-	if ((fp = x2sys_fopen (file, "r")) == NULL) {
-  		fprintf (stderr, "%s : Cannot find track list file %s in either current or X2SYS_HOME directories\n", GMT_program, line);
-		return (GMT_GRDIO_FILE_NOT_FOUND);
-	}
-	
-	p = (char **) GMT_memory (VNULL, (size_t)n_alloc, sizeof (char *), GMT_program);
-	T = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (double), GMT_program);
-
-	while (fgets (line, BUFSIZ, fp)) {
-		GMT_chop (line);	/* Remove trailing CR or LF */
-		sscanf (line, "%s %s", name, date);
-		p[n] = (char *) strdup (name);
-		if (date[strlen(date)-1] != 'T') strcat (date, "T");
-		if (GMT_scanf (date, GMT_IS_ABSTIME, &T[n]) == GMT_IS_NAN) T[n] = GMT_d_NaN;
-		
-		n++;
-		if (n == n_alloc) {
-			n_alloc <<= 1;
-			p = (char **)  GMT_memory ((void *)p, (size_t)n_alloc, sizeof (char *), GMT_program);
-			T = (double *) GMT_memory ((void *)T, (size_t)n_alloc, sizeof (double), GMT_program);
-		}
-	}
-	fclose (fp);
-
-	p = (char **)  GMT_memory ((void *)p, (size_t)n, sizeof (char *), GMT_program);
-	T = (double *) GMT_memory ((void *)T, (size_t)n, sizeof (double), GMT_program);
-
-	*list = p;
-	*start = T;
-	*nf = n;
-
-	return (X2SYS_NOERROR);
-}
-#endif
